function [y]=symm_aconv(sf,x)
y=[];
// symm_aconv -- Symmetric Convolution Tool for Two-Scale Transform
//  Usage
//    y = symm_aconv(sf,x)
//  Inputs
//    sf   symmetric filter
//    x    1-d signal
//  Outputs
//    y    filtered result
// 
//  Description
//    Filtering by periodic convolution of x with the
//    time-reverse of sf.
// 
//  See Also
//    symm_iconv, UpDyadHi_PBS, UpDyadLo_PBS, DownDyadHi_PBS, DownDyadLo_PBS
// 
 
 
//! unknown arg type, using mtlb_length 
n = length(x);
 
//! unknown arg type, using mtlb_length 
p = mtlb_length(sf);
if p<n then
  xpadded = [x,x(1:p)];
else
  z = zeros(1,p);
  for i = 1:p
    %v2$1 = i-1
    imod = 1+%v2$1-fix(%v2$1./n).*n;
    %v2 = x(imod)
    z(1,i) = %v2(:).';
  end
  xpadded = [x,z];
end
 
fflip = reverse(sf);
ypadded = mtlb_filter(fflip,1,xpadded);
 
if p<n then
  y = [ypadded(n+1:n+p),ypadded(p+1:n)];
else
  for i = 1:n
    %v2$1 = p+i-1
    imod = 1+%v2$1-fix(%v2$1./n).*n;
    y(1,imod) = ypadded(p+i);
  end
end
 
shift = (p-1)/2;
%v$1 = shift-1
shift = 1+%v$1-fix(%v$1./n).*n;
y = [y(1+shift:n),y(1:shift)];
 
// 
// Copyright (c) 1995. Shaobing Chen and David L. Donoho
//     
 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
