function [skellist,skelptr,skellen]=BuildSkelMapFast(maxmap)
skellist=[];skelptr=[];skellen=[];
// BuildSkelMapFast -- Chain together Ridges of Wavelet Transform
//  Usage
//    [skellist,skelptr,skellen] = BuildSkelMapFast(maxmap)
//  Inputs
//    maxmap    matrix MMWT
//  Outputs
//    skellist  storage for list of chains
//    skelptr   vector of length nchain -- pointers to head of chain
//    skellen   vector of length nchain -- length of skellists
// 
//  Description
//    A chain is a list of maxima at essentially the same position
//    across a range of scales. 
//    It is identified from the maxmap data structure output by WTMM
//    by finding a root at coarse scales and identifying the closest
//    maxima at the next finest scale.
//    NO PROVISION IS MADE FOR 'terminating' A CHAIN before the
//    finest scale is reached.
// 
//    nchain = len(skellen) chains are found.
//    A chain data structure is a list of scale-location pairs
//    All chains are stored together in skellist.
//    The k-th list begins in skellist at skelptr(k)
//    The k-th list has length skellen(k)
// 
//  See Also
//    CWT, WTMM, PlotSkelMap, BuildSkelMap, ExtractRidge
// 
 
 
//!! Unknown function CalcCWTPars ,the original calling sequence is used
[n,nscale,nvoice,noctave] = CalcCWTPars(size(maxmap));
 
nchain = 0;
%v=size(maxmap)
chains = zeros(%v(1),%v(2));
count = 0;
 
chainset = [];
currpos = [];
 
for k = 1:nscale
  if (k-fix(k./10).*10)==1 then
    mtlb_fprintf('BuildSkelMap: at scale %i:',k);
    mtlb_fprintf('nchains %i, #chainset %i\n',nchain,max(size(chainset)));
  end
   
  // match existing features with finer scale features
  mindist = n/2*(2^(-k/nvoice));
   
  if ~(chainset==[]) then
    for l = 1:max(size(chainset))
      ipos = currpos(l);
      j = matrix(find(maxmap(:,k)),1,-1)';
      circdist = min([abs(j-ipos);abs(j-ipos+n);abs(j-ipos-n)]);
      [dist,pos] = min(circdist);
       
      if pos==[] then
        kill = 1;
      elseif dist(1)>mindist then
        kill = 1;
      else
        ipos = j(pos(1));
        kill = 0;
        maxmap(ipos,k) = 0;
      end
      // in principle could also test amplitude.
       
      if kill then
        // kill current chain
        chains(chainset(l),k) = 0;
        chainset(1,l) = 0;
        currpos(1,l) = 0;
      else
        // grow current chain. 
        chains(chainset(l),k) = ipos;
        count = count+1;
        currpos(1,l) = ipos;
      end
    end
  end
   
  // look for roots of new chains, add them to chain list
   
  j = matrix(find(maxmap(:,k)),1,-1);
  if ~(j==[]) then
    ochain = nchain+1;
    for i = 1:max(size(j))
      nchain = nchain+1;
      chains(nchain,k) = j(i);
      count = count+1;
    end
     
    chainset = [chainset,ochain:nchain];
    currpos = [currpos,chains(ochain:nchain,k)'];
  end
   
  // clear out dead wood
   
  if ~(chainset==[]) then
    j = matrix(find(chainset),1,-1);
    chainset = chainset(j);
    currpos = currpos(j);
  end
   
end
 
// built packed lists of chain structures
 
rptr = zeros(1,n);
rlen = zeros(1,n);
pchain = 1;
qchain = 0;
store = zeros(1,2*count);
 
for ch = 1:nchain
   
  if (ch-fix(ch./10).*10)==1 then
    mtlb_fprintf('BuildSkelMap: packing chain %i\n',ch);
  end
   
  rptr(ch) = pchain
  j = matrix(find(chains(ch,:)),1,-1);
  iscale = j(1);
  rlen(ch) = max(size(j))
  //fprintf('chain %i at %i length %i',ch,pchain,rlen(ch)),
  ix = iscale:iscale+rlen(ch)-1;
  vec = [ix;chains(ch,ix)];
  qchain = pchain+2*rlen(ch)-1;
  %v1 = vec(:)
  store(1,pchain:qchain) = %v1(:).';
  pchain = qchain+1;
end
 
skelptr = rptr(1:nchain);
skellen = rlen(1:nchain);
skellist = store(1:qchain);
 
 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
