function [tau]=CalcMomentGenFun(z,scale,loscale,hiscale)
tau=[];
[nargout,nargin] = argn(0)
// CalcMomentGenFun -- Calculate Moment Generating Function
//  Usage
//    tau = CalcMomentGenFun(z,a,loscale,hiscale)
//  Inputs
//    z         matrix nexp by nscale of z(q,a) ``Thermo Partition Func''
//    a         list of scales 
//    loscale   optional min scale to fit line by
//    hiscale   optional max scale to fit line by 
//  Outputs
//    tau       vector 1 by nscale of moments
// 
//  Description
//    tau(q) = Slope [ log(z(q,a))  versus log(a) ]
// 
//  See Also
//    CalcThermoPartition
// 
 
if nargin<3 then
  loscale = 0;
  hiscale = 10^32;
end
 
 
[nq,nscale] = size(z);
tau = zeros(nq,1);
if nscale~=size(scale) then
  disp('CalcMomentGenFun: no match between z and a');
end
 
window = (loscale<=scale)&(scale<=hiscale);
ix = matrix(find(window),1,-1);
if max(size(ix))>1 then
  for kq = 1:nq
    y = log(z(kq,ix));
     
    //! mtlb_mean(y) may be replaced by 
    //!   mean(y) if yis a vector
    //!   mean(y,1) if yis a matrix
    y = y-mtlb_mean(y);
    x = log(scale(ix));
    x = x-mean(x);
     
    //! mtlb_sum(y .* x) may be replaced by 
    //!     sum(y .* x) if y .* xis a vector
    //!     sum(y .* x,1) if y .* xis a matrix
    %v2 = mtlb_sum(y .* x)/sum(x .* x)
    tau(kq,1) = %v2(:);
  end
else
  disp('CalcMomentGenFun: not enough data to determine slope');
end
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
