function [z]=CalcThermoPartition(cw,mm,q)
z=[];
[nargout,nargin] = argn(0)
// CalcThermoPartition -- Build Thermodynamic Partition Function
//  Usage
//    z = CalcThermoPartition(cw,mm,q)
//  Inputs
//    cw        matrix output by CWT
//    mm        maxmap output by MMWT
//    q         optional list of exponents default linspace(-2,5,61)
//  Outputs
//    z         matrix nexp by nscale of z(q,a)
// 
//  Description
//    z(q,a) = sum_i( |CWT(a,b(i))|^q ),  where b = (b(i)) is a list
//    of wavelet transform maxima  
// 
//  See Also
//    CWT, WTMM
// 
 
if nargin<3 then
  q = linspace(-2,5,61);
end
 
[n,nscale] = size(cw);
for k = 1:nscale
  j = matrix(find(mm(:,k)),1,-1);
  if ~(j==[]) then
    C = abs(cw(j,k));
     
    //! unknown arg type, using mtlb_length 
    for i = 1:mtlb_length(q)
       
      //! mtlb_sum(C.^q(i)) may be replaced by 
      //!     sum(C.^q(i)) if C.^q(i)is a vector
      //!     sum(C.^q(i),1) if C.^q(i)is a matrix
      z(i,k) = mtlb_sum(C.^q(i));
    end
  else
    z(:,k) = %eps^q;
  end
end
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
