function [ridge]=ExtractRidge(ridgenum,wt,skellist,skelptr,skellen,oct,sc)
ridge=[];
[nargout,nargin] = argn(0)
// ExtractRidge -- Pull One Ridge Continuous Wavelet Transform
//  Usage
//    ridge = ExtractRidge(ridgenum,wt,skellist,skelptr,skellen)
//  Inputs
//    ridgenum  index of ridge to extract, 1 <= ridgenum <= nchains
//    wt        continuous wavelet transform output by CWT
//    skellist  storage for list of chains
//    skelptr   vector of length nchain -- pointers to heads of chains
//    skellen   vector of length nchain -- length of skellists
//  Outputs
//  ridge    len by 2 array of numbers, 
//              each row is a scale, amplitude pair
// 
//  Description
//    The amplitude of the wavelet transform is followed along the
//    ridge chain. 
// 
//  See Also
//    CWT, WTMM, BuildSkelMap, PlotSkelMap
// 
if nargin<6 then
  oct = 2;
  sc = 4;
end
 
//! unknown arg type, using mtlb_length 
nchain = mtlb_length(skelptr);
[n,nscale] = size(wt);
noctave = log(n)/log(2)-oct;
nvoice = nscale/noctave;
 
if ridgenum<1|ridgenum>nchain then
  mtlb_fprintf('ridge #%i not in range (1,%i)\n',ridgenum,nchain);
end
 
 
//! mtlb_e(skelptr,ridgenum) may be replaced by skelptr(ridgenum)
//!    skelptr(ridgenum) if skelptr is a vector,
//!    skelptr(ridgenum).' if skelptr is a matrix.
head = mtlb_e(skelptr,ridgenum);
 
//! mtlb_e(skellen,ridgenum) may be replaced by skellen(ridgenum)
//!    skellen(ridgenum) if skellen is a vector,
//!    skellen(ridgenum).' if skellen is a matrix.
len = mtlb_e(skellen,ridgenum);
 
ridge = zeros(len,2);
 
vec = zeros(2,len);
ix = head:head+2*len-1;
vec(:) = skellist(ix);
 
for i = 1:len
  iscale = vec(1,i);
  ipos = vec(2,i);
  scale = 2+oct-log(sc)/log(2)+iscale/nvoice;
  amp = log(abs(wt(ipos,iscale)))/log(2);
  ridge(i,1) = scale;
  ridge(i,2) = amp;
end
 
 
 
 
 
//   
// Originally Part of WaveLab Version .701
// 
// Modified by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
