function []=ImageCWT(cwt,scaling,colors,option,oct,scale)
[nargout,nargin] = argn(0)
// ImageCWT -- Image of Continuous Wavelet Transform
//  Usage
//    ImageCWT(cwt,scaling,colors)
//  Inputs
//    cwt      matrix produced by CWT
//    scaling  string, 'Overall', 'Individual'
//    colors   string  argument for colormap
//    option   'lin' or 'log' for the type of display
//    oct      Default=2
//    scale    Default=4
// 
//  Side Effects
//    Image Display of Continuous Wavelet Transform
// 
if nargin<5 then
  oct = 2;
  scale = 4;
end
if nargin<4 then
  option = 'log';
end
sz = size(cwt);
n = sz(1);
nscale = sz(2);
noctave = floor(log(n)/log(2))-2;
nvoice = nscale ./ noctave;
 
if option=='log' then
  ytix = linspace(1+oct-floor(log(scale)/log(2)),log(n)/log(2)-oct,nscale);
  xtix = linspace(0,n,n);
else
  xtix = linspace(0,n,n);
  ytix = linspace(fix(n/2),0,fix(nscale));
end
 
if scaling=='Individual' then
  for k = 1:nscale
    goodstart = min(n/2 .* (2^(-k/nvoice)),n/4);
     
    //! mtlb_min(cwt(fix(goodstart):fix(n-goodstart),k)) may be replaced by 
    //!   min(cwt(fix(goodstart):fix(n-goodstart),k)) if cwt(fix(goodstart):fix(n-goodstart),k)is a vector
    //!   min(cwt(fix(goodstart):fix(n-goodstart),k),'r') if cwt(fix(goodstart):fix(n-goodstart),k)is a matrix
    amin = mtlb_min(cwt(fix(goodstart):fix(n-goodstart),k));
     
    //!  mtlb_max(cwt(fix(goodstart):fix(n-goodstart),k)) may be replaced by 
    //!     max(cwt(fix(goodstart):fix(n-goodstart),k)) if cwt(fix(goodstart):fix(n-goodstart),k)is a vector
    //!     max(cwt(fix(goodstart):fix(n-goodstart),k),'r') if cwt(fix(goodstart):fix(n-goodstart),k)is a matrix
    amax = mtlb_max(cwt(fix(goodstart):fix(n-goodstart),k));
    cwt(:,k) = (cwt(:,k)-amin) ./ (amax-amin) .* 256;
  end
else
   
  //! mtlb_min(cwt) may be replaced by 
  //!   min(cwt) if cwtis a vector
  //!   min(cwt,'r') if cwtis a matrix
   
  //! mtlb_min(mtlb_min(cwt)) may be replaced by 
  //!   min(mtlb_min(cwt)) if mtlb_min(cwt)is a vector
  //!   min(mtlb_min(cwt),'r') if mtlb_min(cwt)is a matrix
  amin = mtlb_min(mtlb_min(cwt));
   
  //!  mtlb_max(cwt) may be replaced by 
  //!     max(cwt) if cwtis a vector
  //!     max(cwt,'r') if cwtis a matrix
   
  //!  mtlb_max(mtlb_max(cwt)) may be replaced by 
  //!     max(mtlb_max(cwt)) if mtlb_max(cwt)is a vector
  //!     max(mtlb_max(cwt),'r') if mtlb_max(cwt)is a matrix
  amax = mtlb_max(mtlb_max(cwt));
  cwt = (cwt+amax) ./ (2*amax) .* 256;
end
 
if option=='lin' then
  %v1 = cwt'
   
  //!! Unknown function image ,the original calling sequence is used
  image(xtix,ytix,%v1($:-1:1,:));
   
  //!! Unknown function axis ,the original calling sequence is used
  axis('xy');
else
   
  //!! Unknown function image ,the original calling sequence is used
  image(xtix,ytix,cwt');
   
  //!! Unknown function axis ,the original calling sequence is used
  axis('ij');
  xtitle(' ','',' ');
  xtitle(' ',' ','log2(s)');
end
str = mtlb_sprintf('colormap(1-%s(256))',colors);
 
//! mtlb_eval can be replaced by evstr if str
//! is a valid scilab instruction
mtlb_eval(str);
//   
// Originally Part of WaveLab Version .701
// 
// Modified by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
