function []=ImageRWT(rwt,scaling,colors,option,oct,scale)
[nargout,nargin] = argn(0)
// ImageRWT -- Image of Continuous Wavelet Transform
//  Usage
//    ImageRWT(rwt,scaling,colors)
//  Inputs
//    rwt      matrix produced by RWT
//    scaling  string, 'Overall', 'Individual'
//    colors   string  argument for colormap
//    option   'lin' or 'log' for the type of display
// 
//  Side Effects
//    Image Display of Continuous Wavelet Transform
// 
if nargin<5 then
  oct = 2;
  scale = 4;
end
if nargin<4 then
  option = 'log';
end
sz = size(rwt);
n = sz(1);
nscale = sz(2);
noctave = floor(log(n)/log(2))-2;
nvoice = nscale ./ noctave;
 
//  rwt = fliplr(rwt);
if option=='log' then
  ytix = linspace(2+oct-floor(log(scale)/log(2)),log(n)/log(2)+2-floor(log(scale)/log(2)),nscale);
  //   ytix   = linspace(1+(oct-floor(log2(scale))),log2(n)-oct,nscale);
  xtix = linspace(0,n,n);
else
  xtix = linspace(0,n,n);
  //   ytix   = linspace(n/2,0,nscale);
  ytix = linspace(2^(2+oct-floor(log(scale)/log(2))),n*2/scale,nscale);
end
 
if scaling=='Individual' then
  for k = 1:nscale
    //      goodstart = min(n/2 .* 2^(-k/nvoice), n/4);
    //   amin = min(rwt(goodstart:(n-goodstart),k));
    //      amax  = max((rwt(goodstart:(n-goodstart),k)));
     
    //!  mtlb_max(rwt(:,k)) may be replaced by 
    //!     max(rwt(:,k)) if rwt(:,k)is a vector
    //!     max(rwt(:,k),'r') if rwt(:,k)is a matrix
    amax = mtlb_max(rwt(:,k));
     
    //! mtlb_min(rwt(:,k)) may be replaced by 
    //!   min(rwt(:,k)) if rwt(:,k)is a vector
    //!   min(rwt(:,k),'r') if rwt(:,k)is a matrix
    amin = mtlb_min(rwt(:,k));
    rwt(:,k) = (rwt(:,k)-amin) ./ (amax-amin) .* 256;
  end
else
   
  //! mtlb_min(rwt) may be replaced by 
  //!   min(rwt) if rwtis a vector
  //!   min(rwt,'r') if rwtis a matrix
   
  //! mtlb_min(mtlb_min(rwt)) may be replaced by 
  //!   min(mtlb_min(rwt)) if mtlb_min(rwt)is a vector
  //!   min(mtlb_min(rwt),'r') if mtlb_min(rwt)is a matrix
  amin = mtlb_min(mtlb_min(rwt));
   
  //!  mtlb_max(rwt) may be replaced by 
  //!     max(rwt) if rwtis a vector
  //!     max(rwt,'r') if rwtis a matrix
   
  //!  mtlb_max(mtlb_max(rwt)) may be replaced by 
  //!     max(mtlb_max(rwt)) if mtlb_max(rwt)is a vector
  //!     max(mtlb_max(rwt),'r') if mtlb_max(rwt)is a matrix
  amax = mtlb_max(mtlb_max(rwt));
  //      rwt = (rwt-amin) ./ (amax-amin) .*256;
  rwt = (rwt+amax) ./ (2*amax) .* 256;
end
 
if option=='lin' then
  %v1 = rwt'
   
  //!! Unknown function image ,the original calling sequence is used
  image(xtix,ytix,%v1($:-1:1,:));
   
  //!! Unknown function axis ,the original calling sequence is used
  axis('xy');
else
   
  //!! Unknown function image ,the original calling sequence is used
  image(xtix,ytix,rwt');
   
  //!! Unknown function axis ,the original calling sequence is used
  axis('ij');
  xtitle(' ','',' ');
  xtitle(' ',' ','log2(s)');
end
str = mtlb_sprintf('colormap(1-%s(256))',colors);
 
//! mtlb_eval can be replaced by evstr if str
//! is a valid scilab instruction
mtlb_eval(str);
 
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
