function []=PlotGenFracDimen(d,q,scales)
[nargout,nargin] = argn(0)
// PlotGenFracDimen -- Plot Generalized Fractal Dimension Function
//  Usage
//    PlotGenFracDimen(d,q,scale)
//  Inputs
//    d         matrix output by CalcGenFracDimen
//    q         optional list of exponents default linspace(-2,5,61)
//    scales    optional list of scales
// 
//  Side Effects
//    Display D(q,a)   
// 
//  See Also
//    CWT, WTMM, CalcThermoPartition
// 
 
if nargin<3 then
  scales = 1;
end
if nargin<2 then
  q = linspace(-2,5,61);
end
if q==[] then
  q = linspace(-2,5,61);
end
 
[nrow,ncol] = size(d);
 
if ncol==1 then
  mtlb_plot(q,d);
  xtitle('Generalized Fractal Dimension',' ',' ');
  xtitle(' ','Exponent q',' ');
  xtitle(' ',' ','D(q)');
   
  //! mtlb_min(q) may be replaced by 
  //!   min(q) if qis a vector
  //!   min(q,'r') if qis a matrix
   
  //!  mtlb_max(q) may be replaced by 
  //!     max(q) if qis a vector
  //!     max(q,'r') if qis a matrix
   
  //!! Unknown function axis ,the original calling sequence is used
  axis([mtlb_min(q),mtlb_max(q),-1,2]);
else
  for k = 1:nrow
    mtlb_semilogx(scales,d(k,:));
    mtlb_hold('on');
    xstring(scales(1)*0.8,d(k,1),mtlb_sprintf('q=%5.2f',q(k)));
  end
  xtitle('Generalized Fractal Dimension',' ',' ');
  xtitle(' ','Scale a',' ');
  xtitle(' ',' ','D(q,a)');
   
  //! mtlb_min(scales) may be replaced by 
  //!   min(scales) if scalesis a vector
  //!   min(scales,'r') if scalesis a matrix
   
  //!  mtlb_max(scales) may be replaced by 
  //!     max(scales) if scalesis a vector
  //!     max(scales,'r') if scalesis a matrix
   
  //!! Unknown function axis ,the original calling sequence is used
  axis([mtlb_min(scales)/2,mtlb_max(scales)*2,-1,2]);
  mtlb_hold('off');
end
 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
