function []=PlotThermoPartition(sq,z,cw,scales,q)
[nargout,nargin] = argn(0)
// PlotThermoPartition -- Plot Thermodynamic Partition Function
//  Usage
//    PlotThermoPartition(sq,z,cw,q)
//  Inputs
//    sq        selected scales, if empty, linspace(-2,5,7)
//    z         matrix output by CalcThermoPartition
//    cw        matrix output by CWT
//    scales
//    q         optional list of exponents default linspace(-2,5,61)
//  Side Effects
//    z(q,a) = sum_i( |CWT(a,b(i))|^q ),  where b = (b(i)) is a list
//    of wavelet transform maxima  
// 
//  See Also
//    CWT, WTMM, CalcThermoPartition
// 
 
if sq==[] then
  sq = linspace(-2,5,7);
end
 
if nargin<5 then
  q = linspace(-2,5,61);
end
 
[n,nscale] = size(cw);
// noctave = floor(log2(n))-5;
noctave = floor(log(n)/log(2))-2;
// nvoice  = nscale / noctave
// scales  = (2 + (1:nscale)/nvoice);
 
 
//! unknown arg type, using mtlb_length 
for k = 1:mtlb_length(sq)
  j = find(sq(k)==q)';
  if j==[] then
    mtlb_fprintf('Exponent %g not found in q\n',sq(k));
  end
  //  loglog(scales,z(j,:)); hold on;
   
  //!! Unknown function reverse ,the original calling sequence is used
  mtlb_plot(log(reverse(scales))/log(2),log(z(j,:))/log(2));
  mtlb_hold('on');
  //  text(scales(1)*.8,z(j,1),sprintf('q=%5.2f',sq(k)));
   
  //! unknown arg type, using mtlb_length 
  xstring(log(scales(1))/log(2)*0.98,log(z(j,mtlb_length(z(j,:))))/log(2),mtlb_sprintf('q=%5.2f',sq(k)));
end
xtitle('Thermodynamic Partition Function',' ',' ');
// xlabel('scale a')
// ylabel('Z(q,a)')
xtitle(' ','log2(s)',' ');
xtitle(' ',' ','log2(Z(q,s))');
 
mtlb_hold('off');
 
 
 
 
//   
// Originally Part of WaveLab Version .701
//   
// Modified by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
