function [SkelMap,SkelPtr,SkelLen]=PruneSkelMap(cw,dynrange,persist,skelmap,skelptr,skellen)
SkelMap=[];SkelPtr=[];SkelLen=[];
// PruneSkelMap -- Remove Thin Bones in Skeleton of Continuous Wavelet Transform
//  Usage
//    [skellist,skelptr,skellen] = PruneSkelMap(cw,dynrange,persist,skm,skp,skl)
//  Inputs
//    cw         signal length
//    dynrange   kill branch when it reaches amplitude less than this fraction of level norm 
//    persist    kill branch if it doesn't span persist octaves
//    skm        storage for list of chains
//    skp        vector of length nchain -- pointers to heads of chains
//    skl        vector of length nchain -- length of skellists
//  Outputs
//    skellist   storage for list of chains
//    skelptr    vector of length nchain --pointers to heads of chain
//    skellen    vector of length nchain -- length of skellists
// 
//  Description
//    Backwards pruning of ``weak amplitudes'': i.e. amplitudes
//      smaller than dynrange * norm at scale a 
// 
//    Ridges are deleted from skeleton if
//      they Fail to have a length greater than persist octaves
//    
//  See Also
//    BuildSkelMap, ExtractRidge, PlotSkelMap
// 
 
[n,nscale,nvoice,noctave] = CalcCWTPars(size(cw));
 
//! unknown arg type, using mtlb_length 
nchain = mtlb_length(skelptr);
 
amax = CalcCWTNorms(cw);
mtlb_fprintf('PruneSkelMap: Started with nchain:%i\n',nchain);
for k = 1:nchain
  // bottom-up pruning of chains 
  if (k-fix(k./10).*10)==1 then
    mtlb_fprintf('PruneSkelMap: pruning chain %i\n',k);
  end
  vec = zeros(2,skellen(k));
  ix = skelptr(k):skelptr(k)+2*skellen(k)-1;
  vec(:) = skelmap(ix);
  pvec = [vec(1,:)',vec(2,:)'];
  nx = pvec(:,2)+nscale*(pvec(:,1)-1);
  big = abs(cw(nx))>dynrange .* amax(pvec(:,1))';
  j = find(big)';
  if ~(j==[]) then
     
    //! skellen = mtlb_i(skellen,k,j(max(size(j)))) may be replaced by skellen(k) = j(max(size(j)))
    //!   if skellen is not a  vector
    //!   or if skellen and j(max(size(j))) are both row or column vectors
    skellen = mtlb_i(skellen,k,j(max(size(j))))
  else
     
    //! skellen = mtlb_i(skellen,k,0) may be replaced by skellen(k) = 0
    //!   if skellen is not a  vector
    //!   or if skellen and 0 are both row or column vectors
    skellen = mtlb_i(skellen,k,0)
  end
end
 
// prune chains that don't last
 
nlast = nvoice .* persist;
 
for k = 1:nchain
  if skellen(k)<nlast then
     
    //! skellen = mtlb_i(skellen,k,0) may be replaced by skellen(k) = 0
    //!   if skellen is not a  vector
    //!   or if skellen and 0 are both row or column vectors
    skellen = mtlb_i(skellen,k,0)
  end
end
 
// Remove Chains that have been marked pruned
 
 
//! mtlb_sum(skellen) may be replaced by 
//!     sum(skellen) if skellenis a vector
//!     sum(skellen,1) if skellenis a matrix
Nspace = mtlb_sum(skellen);
 
//! mtlb_sum(skellen~=0) may be replaced by 
//!     sum(skellen~=0) if skellen~=0is a vector
//!     sum(skellen~=0,1) if skellen~=0is a matrix
Nchain = mtlb_sum(skellen~=0);
SkelMap = zeros(1,2*Nspace);
SkelPtr = zeros(1,Nchain);
SkelLen = zeros(1,Nchain);
 
kchain = 1;
qstore = 0;
for k = 1:nchain
  if (kchain-fix(kchain./10).*10)==1 then
    mtlb_fprintf('BuildSkelMap: packing chain %i\n',kchain);
  end
  if skellen(k)~=0 then
    pstore = qstore+1;
    mstore = skelptr(k);
    qstore = pstore-1+2*skellen(k);
    nstore = mstore-1+2*skellen(k);
    %v2 = skellen(k)
    SkelLen(1,kchain) = %v2(:).';
    SkelPtr(kchain) = pstore
    SkelMap(pstore:qstore) = skelmap(mstore:nstore)
    kchain = kchain+1;
  end
end
mtlb_fprintf('PruneSkelMap: Ended with kchain:%i\n',kchain);
 
 
 
 
 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
