function [rwt]=RWT(x,nvoice,wavelet,oct,scale)
rwt=[];
[nargout,nargin] = argn(0)
// RWT -- Real Wavelet Transform
//  Usage
//    rwt = RWT(x,nvoice,wavelet)
//  Inputs
//    x        signal, dyadic length n=2^J, real-valued
//    nvoice   number of voices/octave
//    wavelet  string 'Gauss', 'DerGauss','Sombrero', 'Morlet'
//  Outputs
//    rwt      matrix n by nscale where
//             nscale = nvoice .* noctave
// 
//  Description
//     see sections 4.3.1 and 4.3.3 of Mallat's book  
// 
if nargin<4 then
  oct = 2;
  scale = 4;
end
// preparation
 
//!! Unknown function ShapeAsRow ,the original calling sequence is used
x = ShapeAsRow(x);
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(x);
 
//! mtlb_fft(x) may be replaced by 
//!      fft(x,-1) if xis a vector
xhat = mtlb_fft(x);
xi = [0:n/2,-n/2+1:-1] .* (2*%pi/n);
 
// root
omega0 = 5;
 
// noctave = floor(log2(n))-2;
// noctave = floor(log2(n))-1;
noctave = floor(log(n)/log(2))-oct;
nscale = nvoice .* noctave;
 
rwt = zeros(n,nscale);
 
kscale = 1;
// scale   = 4;
// scale = 16;
 
for jo = 1:noctave
  for jv = 1:nvoice
    qscale = scale .* (2^(jv/nvoice));
    omega = n .* xi ./ qscale;
    if wavelet=='Gauss' then
      window = exp(-omega.^2 ./ 2);
    elseif wavelet=='DerGauss' then
      window = %i .* omega .* exp(-omega.^2 ./ 2);
    elseif wavelet=='Sombrero' then
      window = omega.^2 .* exp(-omega.^2 ./ 2);
    elseif wavelet=='Morlet' then
      window = exp(-(omega-omega0).^2 ./ 2)-exp(-(omega.^2+omega0.^2)/2);
    end
    //(  Renormalisation comme dans le bouquin )
    window = window ./ sqrt(qscale);
    %what = window .* xhat;
    w = fft(%what,1);
    rwt(1:n,kscale) = real(w)';
    kscale = kscale+1;
  end
  scale = scale .* 2;
end
// kscale = 1 -> low frequencies
// the matrix rwt is ordered from low to high frequencies 
 
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
