function [scale]=RWTscale(sig,cwt)
scale=[];
// CWTscale -- Complement to Continuous Wavelet Transform
//  Usage
//    scale = CWTscale(sig,cwt);
//  Inputs
//    sig      1-d signal
//    cwt      continous wavelet transform of sig, Output from CWT(sig)
//  Outputs
//    scale    complement of continuous wavelet Transform of sig
//  Side Effects   
//  Description
//     scale = fft(sig) - sum(columns of cwt)
//  Algorithm
//     
//  Examples
//     N = 1024;     % signal length; 
//     nvoice = 12;  
//     % create a Brownian
//     CantorMeasure = MakeFractal(N,3,'Deterministic',[.5 0 .5]);
//     Devil  = cumsum(CantorMeasure); t = (.5:(N-.5))./N;
//     figure; plot(t, Devil); title(sprintf(' Devil Staircase Signal'));
//     % make CWT
//     Devil_cwt = CWT(Devil,nvoice,'Sombrero');
//     % complement to CWT
//     scale = CWTscale(Devil,Devil_cwt);
//     plot(real(scale));
//  See Also
//    CWT   iCWT
//  References
//    Mallat, """"Wavelet Signal Processing""""; 4.?.?
//    
sz = size(cwt);
 
pause

fftsig = fft(sig(:),-1);
for i = 1:sz(2)
   
  //! mtlb_fft(cwt(:,i)) may be replaced by 
  //!      fft(cwt(:,i),-1) if cwt(:,i)is a vector
  fftsig = fftsig-fft(cwt(:,i),-1);
end
scale = fft(fftsig,1);
 
 
// 
// Copyright (c) 1996. Xiaoming Huo
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
