function [localmaxima]=Ridge_AWT(m,par,ABS)
localmaxima=[];
[nargout,nargin] = argn(0)
// Ridge_AWT -- Ridges of an Analytic Wavelet Transform
//  Usage
//    localmaxima = Ridge_AWT(m,par,ABS);
//  Inputs
//    m          input matrix
//    par       parameter, 2*par is how many neighbours to compare
//    ABS   flag, compare by absolute value(1) or not(0)
//  Outputs
//    localmaxima  local maxima of every column, binary matrix same size
//    as m.
//  Description
//    see section 4.4.2 of Mallat's book
//  Algorithm
//    Get the local maxima first, then compare with original value
//  References
// 
if nargin<3 then
  ABS = 1;
end
 
if nargin<2 then
   
end
 
if ABS then
  m = abs(m);
end
 
[nrows,ncols] = size(m);
%v=size(m)
localmaxima = zeros(%v(1),%v(2));
 
 
t = 1:nrows;
 
//!! Unknown function rshift ,the original calling sequence is used
tplus = rshift(t);
 
//!! Unknown function lshift ,the original calling sequence is used
tminus = lshift(t);
 
//!  mtlb_max(abs(m)) may be replaced by 
//!     max(abs(m)) if abs(m)is a vector
//!     max(abs(m),'r') if abs(m)is a matrix
 
//!  mtlb_max(mtlb_max(abs(m))) may be replaced by 
//!     max(mtlb_max(abs(m))) if mtlb_max(abs(m))is a vector
//!     max(mtlb_max(abs(m)),'r') if mtlb_max(abs(m))is a matrix
Thresh = mtlb_max(mtlb_max(abs(m)))/20;
 
for i = 1:ncols
   
  //!! Unknown function ShapeAsRow ,the original calling sequence is used
  x = ShapeAsRow(m(:,i));
  for j = 1:par
     
    //! mtlb_e(x,tplus) may be replaced by x(tplus)
    //!    x(tplus) if x is a vector,
    //!    x(tplus).' if x is a matrix.
     
    //! mtlb_e(x,tminus) may be replaced by x(tminus)
    //!    x(tminus) if x is a vector,
    //!    x(tminus).' if x is a matrix.
     
    //!  mtlb_max([x(t);mtlb_e(x,tplus);mtlb_e(x,tminus)]) may be replaced by 
    //!     max([x(t);mtlb_e(x,tplus);mtlb_e(x,tminus)]) if [x(t);mtlb_e(x,tplus);mtlb_e(x,tminus)]is a vector
    //!     max([x(t);mtlb_e(x,tplus);mtlb_e(x,tminus)],'r') if [x(t);mtlb_e(x,tplus);mtlb_e(x,tminus)]is a matrix
    x = mtlb_max([x(t);mtlb_e(x,tplus);mtlb_e(x,tminus)]);
  end
   
  //!! Unknown function ShapeAsRow ,the original calling sequence is used
  x = ShapeAsRow(x)';
   
  //!  mtlb_max(x) may be replaced by 
  //!     max(x) if xis a vector
  //!     max(x,'r') if xis a matrix
  thresh = mtlb_max(x)/2;
  localmaxima(:,i) = bool2s(~(m(:,i)<x)) .* bool2s(m(:,i)>thresh) .* bool2s(m(:,i)>Thresh);
end
// 
// Copyright (c) 1996. Xiaoming Huo
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
