function [fBr]=MakeBrownian(n,H,par)
fBr=[];
[nargout,nargin] = argn(0)
// MakeBrownian -- Create Fractional Brownian Signal
//  Usage
//    fBr = MakeBrownian(n,H,par)
//  Inputs
//    n       signal length
//    H       base of digits in expansion
//    par     optional, degree of extension in algorithm, default =8.
//  Outputs
//    fBr     (pseudo) Fractional Brownian signal
// 
//  Description
//    Uses a Frequency Domain algorithm to get a pseudo Brownian Motion
//    The law is NOT normalized to give unit variance to unit increments.
// 
if nargin<3 then
  par = 8;
end
N = n .* par;
 
// generate the FT of a real white noise
 
//!! Unknown function WhiteNoise ,the original calling sequence is used
w = WhiteNoise(zeros(1,N));
 
//! mtlb_fft(w) may be replaced by 
//!      fft(w,-1) if wis a vector
%what = mtlb_fft(w);
 
// formal fractional integral
eta = 2*%pi*[0:N/2,-N/2+1:-1] ./ N;
eta(1) = 1
bhat = abs(eta).^(-2*H) .* %what;
 
//! bhat = mtlb_i(bhat,1,0) may be replaced by bhat(1) = 0
//!   if bhat is not a  vector
//!   or if bhat and 0 are both row or column vectors
bhat = mtlb_i(bhat,1,0)
 
//! mtlb_ifft(bhat) may be replaced by 
//!      fft(bhat,1) if bhatis a vector
fBr = mtlb_ifft(bhat);
 
// extract a segment that is well away from the edges
 
start = floor(par/2 .* n);
stop = start+n-1;
fBr = real(fBr(start:stop));
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
