function [img]=MakeImage(Name,n,par)
img=[];
[nargout,nargin] = argn(0)
// MakeImage -- Make artificial 2d signal
//  Usage
//    sig = MakeImage(Name,n[,par])
//  Inputs
//    Name   string, one of:
//      'Backgammon'
//      'BoxWithCross'    (par = length of side [n/2])
//      'Checkerboard'
//      'Circle'          (par = radius [n/4])
//      'FigureEight'
//      'Mondrian'        (par = number [10])  
//      'OvalDiagonal'    (par = major/minor axes ratio [2])
//      'OvalHorizontal'  (par = major/minor axes ratio [2])
//      'OvalVertical'    (par = major/minor axes ratio [2])
//      'StickFigure'
//      'Triangle'
//      'VanishingPoint'
//      'Square'
//    n                   desired signal dimension
//    par                 optional parameter, defaults in []'s above
//  Outputs
//    img                 n by n image
// 
n2 = n/2;
// inline translation of meshgrid(-n2:n2-1,n2-1:-1:-n2)
x=-n2:n2-1
y=matrix(n2-1:-1:-n2,-1,1)
x=x(ones(x),:)
y=y(:,ones(y)')
 
if Name=='Backgammon' then
  // leftmost diamond
   
  //! mtlb_ones(n) can be replaced by :
  //!   ones(n,n) if n is a scalar
  //!   ones(v(1),v(2),'n') if n is the vector v
  img = mtlb_ones(n);
  tmp = makediag(n/2,n/8);
  img(1:n/2,1:n/8) = tmp(:,$:-1:1);
  img(n/2+1:n,1:n/8) = tmp($:-1:1,$:-1:1);
  %v1 = img(1:n,1:n/8)
  img(1:n,n/8+1:n/4) = %v1(:,$:-1:1);
  // rightmost diamond
  img(1:n,n-n/4+1:n) = img(1:n,1:n/4);
  // 2nd diamond
  tmp = makediag(n/2,3*n/32);
  img(1:n/2,n/4+1:n/4+3*n/32) = tmp(:,$:-1:1);
  img(n/2+1:n,n/4+1:n/4+3*n/32) = tmp($:-1:1,$:-1:1);
  %v1 = img(1:n,n/4+1:n/4+3*n/32)
  img(1:n,n/4+3*n/32+1:7*n/16) = %v1(:,$:-1:1);
  //4th diamond
  img(1:n,9*n/16+1:3*n/4) = img(1:n,n/4+1:7*n/16);
  // middle diamond
  tmp = makediag(n/2,n/16);
  img(1:n/2,n/2-n/16+1:n/2) = tmp(:,$:-1:1);
  img(n/2+1:n,n/2-n/16+1:n/2) = tmp($:-1:1,$:-1:1);
  %v1 = img(1:n,n/2-n/16+1:n/2)
  img(1:n,n/2+1:n/2+n/16) = %v1(:,$:-1:1);
   
elseif Name=='BoxWithCross' then
  if nargin<3 then
    par = n/2;
  end
  p2 = par/2;
  img = bool2s(((x==(-p2))&(y<=p2))&(y>=(-p2)))+bool2s(((x==p2)&(y<=p2))&(y>=(-p2)))+bool2s(((y==(-p2))&(x<=p2))&(x>=(-p2)))+bool2s(((y==p2)&(x<=p2))&(x>=(-p2)))+bool2s(((y==x)&(x<=p2))&(x>=(-p2)))+bool2s(((y==(-x))&(x<=p2))&(x>=(-p2)));
  %v1=size(matrix(find(img>1),1,-1))
   
  //! img = mtlb_i(img,matrix(find(img>1),1,-1),ones(%v1(1),%v1(2))) may be replaced by img(matrix(find(img>1),1,-1)) = ones(%v1(1),%v1(2))
  //!   if img is not a  vector
  //!   or if img and ones(%v1(1),%v1(2)) are both row or column vectors
  img = mtlb_i(img,matrix(find(img>1),1,-1),ones(%v1(1),%v1(2)))
   
elseif Name=='Checkerboard' then
   
  //! mtlb_zeros(n) can be replaced by :
  //!  zeros(n,n) if n is a scalar
  //!  zeros(v(1),v(2),'n') if n is the vector v
  img = mtlb_zeros(n);
  for i = 1:n/2
    img(i,1:i) = ones(1,i);
    img(i,n-i+1:n) = ones(1,i);
    img(n-i+1,1:i) = ones(1,i);
    img(n-i+1,n-i+1:n) = ones(1,i);
  end
   
elseif Name=='Circle' then
  if nargin<3 then
    par = n/4;
  end
  img = ((x-0.5).^2+(y-0.5).^2)<=(par^2);
   
elseif Name=='FigureEight' then
  img = (x.^2+y.^2).^2<=2*(n2^2)*x .* y;
   
elseif Name=='Mondrian' then
  if nargin<3 then
    par = 10;
  end
  img = x~=x;
  %v1=getdate()
  rand('seed',sum(100*%v1([1:2 6:9])),'u');
  for i = 1:par
    xp = ceil(n2*rand(1,1,'u'))-n2;
    yp = ceil(n2*rand(1,1,'u'))-n2;
    l = ceil(n2*rand(1,1,'u'));
    h = ceil(n2*rand(1,1,'u'));
    img = bool2s(img)+bool2s((((x>=xp)&(x<=(xp+l)))&(y>=yp))&(y<=(yp+h)));
  end
   
elseif Name=='OvalDiagonal' then
  if nargin<3 then
    par = 2;
  end
  r = (n-10)/(2*par)^2;
  img = ((sqrt(2)*x/2-sqrt(2)*y/2).^2/(par*sqrt(r)^2)+(sqrt(2)*x/2+sqrt(2)*y/2).^2/r)<=1;
   
elseif Name=='OvalHorizontal' then
  if nargin<3 then
    par = 2;
  end
  r = (n-10)/(2*par)^2;
  img = (x.^2/(par*sqrt(r)^2)+y.^2/r)<=1;
   
elseif Name=='OvalVertical' then
  if nargin<3 then
    par = 2;
  end
  r = (n-10)/(2*par)^2;
  img = (x.^2/r+y.^2/(par*sqrt(r)^2))<=1;
   
elseif Name=='StickFigure' then
  p = n/8;
  img = bool2s(((x==0)&(y<=p))&(y>=(-0.75*p)))+bool2s(((x<=0)&(x>=(-p/1.5)))&(y==(x-0.75*p)))+bool2s(((x>=0)&(x<=p/1.5))&(y==(-x-0.75*p)))+bool2s(((x<=0)&(x>=(-p/1.5)))&(y==(-x+p/8)))+bool2s(((x>=0)&(x<=p/1.5))&(y==(x+p/8)))+bool2s((x.^2+(y-4*p/3).^2)<=(p/3^2));
  %v1=size(matrix(find(img>1),1,-1))
   
  //! img = mtlb_i(img,matrix(find(img>1),1,-1),ones(%v1(1),%v1(2))) may be replaced by img(matrix(find(img>1),1,-1)) = ones(%v1(1),%v1(2))
  //!   if img is not a  vector
  //!   or if img and ones(%v1(1),%v1(2)) are both row or column vectors
  img = mtlb_i(img,matrix(find(img>1),1,-1),ones(%v1(1),%v1(2)))
   
elseif Name=='Triangle' then
   
  //! mtlb_zeros(n) can be replaced by :
  //!  zeros(n,n) if n is a scalar
  //!  zeros(v(1),v(2),'n') if n is the vector v
  img = mtlb_zeros(n);
  for i = 1:n
    img(i,1:i) = ones(1,i);
  end
   
elseif Name=='VanishingPoint' then
  img = x~=x;
  p = n/4;
  c = n/4;
  for j = 1:log(p)/log(2)+1
    img = bool2s(img)+bool2s(((x==(c-p))&(y<=(c+p)))&(y>=(c-p)))+bool2s(((x==(c+p))&(y<=(c+p)))&(y>=(c-p)))+bool2s(((y==(c-p))&(x<=(c+p)))&(x>=(c-p)))+bool2s(((y==(c+p))&(x<=(c+p)))&(x>=(c-p)));
    c = c-p;
    p = p/2;
  end
  %v1=size(matrix(find(img>1),1,-1))
   
  //! img = mtlb_i(img,matrix(find(img>1),1,-1),ones(%v1(1),%v1(2))) may be replaced by img(matrix(find(img>1),1,-1)) = ones(%v1(1),%v1(2))
  //!   if img is not a  vector
  //!   or if img and ones(%v1(1),%v1(2)) are both row or column vectors
  img = mtlb_i(img,matrix(find(img>1),1,-1),ones(%v1(1),%v1(2)))
elseif Name=='Square' then
  img = ones(n,n);
  m = n/4;
  pos = m+1:3*m;
  img(pos,pos) = zeros(2*m,2*m);
  img = 1-img;
else
  disp(mtlb_sprintf('MakeImage: I don''t recognize <<%s>>',Name));
  disp('Allowable Names are:');
  disp('Backgammon');
  disp('BoxWithCross');
  disp('Circle');
  disp('FigureEight');
  disp('Mondrian');
  disp('OvalDiagonal');
  disp('OvalHorizontal');
  disp('OvalVertical');
  disp('StickFigure');
  disp('Triangle');
  disp('VanishingPoint');
  disp('Square');
end
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
