function [Image]=ReadImage(Name)
Image=[];
// ReadImage -- Read Image file in 8-bit raw binary format
//  Usage
//    Image = ReadImage(Name)
//  Inputs
//    Name    'Barton', 'Canaletto', 'Coifman', 'Daubechies',
//            'Fingerprint', 'Lincoln', 'Lenna', 'MRIScan', 'Phone'
//  Outputs
//    Image    2-d signal, n by n, n dyadic
// 
//  Side Effects
//    A descriptor file for the data is printed
// 
global('WLVERBOSE');
global('WAVELABPATH');
// set by WavePath.m
global('PATHNAMESEPARATOR');
// set by WavePath.m
// 
if Name=='Barton' then
  filename = 'barton.raw';
  par = [512,512];
  source = 'barton.txt';
elseif Name=='Canaletto' then
  filename = 'canaletto.raw';
  par = [512,512];
  source = 'canaletto.txt';
elseif Name=='Coifman' then
  filename = 'coifman.raw';
  par = [256,256];
  source = 'coifman.txt';
elseif Name=='Daubechies' then
  filename = 'daubechies.raw';
  par = [256,256];
  source = 'daubechies.txt';
elseif Name=='Fingerprint' then
  filename = 'fingerprint.raw';
  par = [512,512];
  source = 'fingerprint.txt';
elseif Name=='Lenna' then
  filename = 'lenna.raw';
  par = [256,256];
  source = 'lenna.txt';
elseif Name=='Lincoln' then
  filename = 'lincoln.raw';
  par = [64,64];
  source = 'lincoln.txt';
elseif Name=='MRIScan' then
  filename = 'mriscan.raw';
  par = [256,256];
  source = 'mriscan.txt';
elseif Name=='Phone' then
  filename = 'phone.raw';
  par = [128,128];
  source = 'phone.txt';
elseif Name=='Barbara' then
  filename = 'barb.raw';
  par = [512,512];
  source = 'barb.txt';
else
  disp('I only know how to read the datasets:            ');
  disp('   Barton, Canaletto, Coifman, Daubechies,       ');
  disp('   Fingerprint, Lincoln, Lenna, MRIScan, Phone   ');
  filename = 'BOGUS';
end
 
if ~(filename=='BOGUS') then
  filename = WAVELABPATH+'Datasets'+PATHNAMESEPARATOR+filename;
  [fid,%v1] = mopen(filename,'r',0)
  if %v1<0 then fid = -1;end
  if fid<0 then
    mtlb_fprintf('ReadImage: I was unable to open the dataset ""%s""',filename);
    disp('Typically way this error could occur       ');
    disp('is by the failure of your WavePath.m file to reflect   ');
    disp('the actual name of the root WaveLab directory.        ');
    disp('Solution: quit Matlab, correctw WavePath, restart Matlab. ');
    disp('In our experience this always works.                  ');
  else
    if WLVERBOSE=='Yes' then
      mtlb_fprintf('Reading %s\n',filename);
      mtlb_fprintf('It is an array of size [%4.0f,%4.0f]\n',par(1),par(2));
      docfile = WAVELABPATH+'Datasets'+PATHNAMESEPARATOR+source;
       
      //! type ignored
      // type(source)
    end
    Image = mtlb_fread(fid,par);
    mclose(fid);
  end
end
 
// 
// Copyright (c) 1993-5. Jonathan Buckheit and David Donoho
// 
// Modified by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
// 
 
//  Revision History
//  1.2 09/29/99 DLD  changed .doc -> .txt
//        changed fid < 0 message.
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
