function [Signal]=ReadSignal(Name)
Signal=[];
// ReadSignal -- Read 1-d signal from file in ascii format
//  Usage
//    signal = ReadSignal(Name)
//  Inputs
//    Name    'Caruso', 'ESCA', 'Greasy', 'HochNMR',
//            'Seismic', 'Laser', 'RaphaelNMR',
//            'Sunspots', 'Transients', 'Tweet'
//  Outputs
//    signal   1-d signal
// 
//  Side Effects
//    A descriptor file for the data is printed
// 
global('WLVERBOSE');
global('WAVELABPATH');
// set by WavePath.m
global('PATHNAMESEPARATOR');
// set by WavePath.m 
// 
if Name=='Tweet' then
  filename = 'tweet';
elseif Name=='Transients' then
  filename = 'transients';
elseif Name=='Sunspots' then
  filename = 'sunspots';
elseif Name=='RaphaelNMR' then
  filename = 'RaphNMR';
elseif Name=='Laser' then
  filename = 'laser';
elseif Name=='Seismic' then
  filename = 'seismic';
elseif Name=='HochNMR' then
  filename = 'HochNMR';
elseif Name=='Greasy' then
  filename = 'greasy';
elseif Name=='ESCA' then
  filename = 'esca';
elseif Name=='Caruso' then
  filename = 'caruso';
elseif Name=='msignal' then
  filename = 'msignal';
elseif Name=='lady' then
  filename = 'lady';
else
  disp('I only know how to read the signals:     ');
  disp('   Caruso, ESCA, Greasy, HochNMR,        ');
  disp('   Seismic, Laser, RaphaelNMR,           ');
  disp('   Sunspots, Transients, Tweet           ');
  filename = 'BOGUS';
end
 
if ~(filename=='BOGUS') then
  filepath = WAVELABPATH+'Datasets'+PATHNAMESEPARATOR+filename+'.asc';
  [fid,%v1] = mopen(filepath,'r',0)
  if %v1<0 then fid = -1;end
  if fid<0 then
    disp('ReadSignal: I was unable to open the dataset you requested        ');
    disp('Practically the only way this error could occur       ');
    disp('is by the failure of the WavePath.m file to reflect   ');
    disp('the actual name of the root WaveLab directory.        ');
    disp('Solution: quit Matlab, edit WavePath, restart Matlab. ');
    disp('In our experience this always works.                  ');
  else
    if WLVERBOSE=='Yes' then
      mtlb_fprintf('Reading %s\n',filepath);
      docpath = WAVELABPATH+'Datasets'+PATHNAMESEPARATOR+filename+'.txt';
       
      //! type ignored
      // type(docpath)
    end
    Signal = mtlb_fscanf(fid,'%g');
    mclose(fid);
    par = size(Signal);
    if WLVERBOSE=='Yes' then
      mtlb_fprintf('It is an array of size[%4.0f,%4.0f]\n',par(1),par(2));
    end
  end
end
 
// 
// Copyright (c) 1993-5, Jonathan Buckheit and David Donoho
// 
 
// Revision History
//  09/29/99 DLD Changed .doc to .txt
//     
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
