function [out]=ThreshWave2(Noisy,%type,TI,sigma,mult,L,qmf)
out=[];
[nargout,nargin] = argn(0)
//  ThreshWave2 -- Denoising of 2-d image with wavelet thresholding.
//  Usage 
//    out=ThreshWave2(Noisy,type,TI,sigma,mult,L,qmf)
//  Inputs
//    Noisy 2-d Noisy image, size(Noisy)= 2^J*2^J.
//    type    'S' for soft thresholding, 'H' for hard thresholding.
//  Optional, Default=hard thresholding.
//    TI  Enter 1 if you want translation-invariant denoising,
//  0 if you don't.
//  Optional, Default=non-invariant. 
//    sigma   Standard deviation of additive Gaussian White Noise.
//  Enter 0 if you want sigma to be estimated by median filtering.
//  Optional, Default=estimated by median filtering.
//    mult    Multiplier of sigma to obtain the value of the threshold.
//            Optional, Default = sqrt(2*log(n)), where n is the
//      number of pixels/
//    L       Low-Frequency cutoff for shrinkage (e.g. L=4)
//            Should have L << J!
//            Optional, Default = 3.
//    qmf     Quadrature Mirror Filter for Wavelet Transform
//            Optional, Default = Symmlet 4.
//  Outputs 
//    out      Estimate, obtained by applying thresholding on
//           wavelet coefficients.
// 
 
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(Noisy);
if nargin<7 then
   
  //!! Unknown function MakeONFilter ,the original calling sequence is used
  qmf = MakeONFilter('Symmlet',4);
end
if nargin<6 then
  L = 3;
end
if nargin<5 then
  mult = sqrt(4*log(n));
end
if nargin<4 then
  [y,coef] = NormNoise(Noisy,qmf);
  sigma = 1/coef;
end
if nargin<3 then
  TI = 0;
end
if nargin<2 then
  %type = 'H';
end
 
if sigma==0 then
  [y,coef] = NormNoise(Noisy,qmf);
  sigma = 1/coef;
end
 
thresh = sigma*mult;
out = zeros(1,n);
 
 
if TI==1 then
  if %type=='S' then
     
    //!! Unknown function TIDenoiseSoft2 ,the original calling sequence is used
    out = TIDenoiseSoft2(Noisy,L,qmf,thresh);
  end
  if %type=='H' then
     
    //!! Unknown function TIDenoiseHard2 ,the original calling sequence is used
    out = TIDenoiseHard2(Noisy,L,qmf,thresh);
  end
else
  if %type=='S' then
    out = ST2(Noisy,L,qmf,thresh);
  else
    out = HT2(Noisy,L,qmf,thresh);
  end
end
 
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
 
 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
