function [xh,wcoef]=WaveShrink(y,%type,L,qmf)
xh=[];wcoef=[];
[nargout,nargin] = argn(0)
// WaveShrink -- Soft Threshold Shrinkage Applied to Wavelet Coefficients
//  Usage 
//    [xh,xwh] = WaveShrink(y,type,L,qmf)
//  Inputs
//    y      1-d signal. length(y)= 2^J
//               Normalized to noise level 1! (See NoiseNorm)
//    type   string. Type of shrinkage applied:
//               'Visu','SURE','Hybrid','MinMax','MAD'
//               Optional; default == 'Visu'
//    L      Low-Frequency cutoff for shrinkage (e.g. L=4)
//               Should have L << J!
//    qmf    Quadrature Mirror Filter for Wavelet Transform
//               Optional, Default = Symmlet 8.
//  Outputs 
//    xh     estimate, obtained by applying soft thresholding on
//           wavelet coefficients
//    xwh    Wavelet Transform of estimate
// 
//  Description
//    WaveShrink smooths noisy data presumed to have noise level 1
//    by transforming it into the wavelet domain, applying soft
//    thresholding to the wavelet coefficients and inverse transforming.
// 
//    The theory underlying these methods is described in a variety of
//    papers by D.L. Donoho and I.M. Johnstone.
// 
//    The different methods of selecting thresholds are detailed
//    in their articles.
// 
//  See Also
//        FWT_PO, IWT_PO, MakeONFilter, NoiseNorm, RigorShrink
// 
if nargin<2 then
  %type = 'Visu';
end
if nargin<3 then
  L = 3;
end
if nargin<4 then
   
  //!! Unknown function MakeONFilter ,the original calling sequence is used
  qmf = MakeONFilter('Symmlet',8);
end
// 
 
//!! Unknown function dyadlength ,the original calling sequence is used
[n,J] = dyadlength(y);
 
//!! Unknown function FWT_PO ,the original calling sequence is used
wcoef = FWT_PO(y,L,qmf);
// 
if %type=='Visu' then
   
  //! wcoef = mtlb_i(wcoef,2^L+1:n,VisuThresh(wcoef(2^L+1:n))) may be replaced by wcoef(2^L+1:n) = VisuThresh(wcoef(2^L+1:n))
  //!   if wcoef is not a  vector
  //!   or if wcoef and VisuThresh(wcoef(2^L+1:n)) are both row or column vectors
  wcoef = mtlb_i(wcoef,2^L+1:n,VisuThresh(wcoef(2^L+1:n)))
elseif %type=='SURE' then
  wcoef = MultiSURE(wcoef,L);
elseif %type=='Hybrid' then
  wcoef = MultiHybrid(wcoef,L);
elseif %type=='MinMax' then
   
  //! wcoef = mtlb_i(wcoef,2^L+1:n,MinMaxThresh(wcoef(2^L+1:n))) may be replaced by wcoef(2^L+1:n) = MinMaxThresh(wcoef(2^L+1:n))
  //!   if wcoef is not a  vector
  //!   or if wcoef and MinMaxThresh(wcoef(2^L+1:n)) are both row or column vectors
  wcoef = mtlb_i(wcoef,2^L+1:n,MinMaxThresh(wcoef(2^L+1:n)))
elseif %type=='MAD' then
  wcoef = MultiMAD(wcoef,L);
end
// 
 
//!! Unknown function IWT_PO ,the original calling sequence is used
xh = IWT_PO(wcoef,L,qmf);
 
// 
// Copyright (c) 1993-5.  Jonathan Buckheit, David Donoho and Iain Johnstone
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
