function [i,j]=StretchMatrix(ie,je,n,L)
i=[];j=[];
// StretchMatrix -- Stretch matrix into BCR nonstandard form
//  Usage
//    [i,j] = StretchMatrix(ie,je,n,L)
//  Inputs
//    ie,je    row/col indices of nonxero elements of matrix
//    n        size of matrix
//    L        number of resolution levels
//  Outputs
//    i,j      row/col indices of elements in nonstandard form
//             of matrix
// 
//  Description
//    To construct the nonstandard form of a matrix, do something
//    like this:
//       [ie,je,s] = find(StdForm)
//       [i,j]     = StretchMatrix(ie,je,n,L)
//       NonStd    = sparse(i,j,s,2*n,2*n)
// 
 
J = floor(log(n+1)/log(2));
for l = J-1:-1:L
  cond = (ie>(2^l)|je>(2^l))&((ie<=(2^(l+1)))&(je<=(2^(l+1))));
  inx = matrix(find(cond),1,-1);
  if ~(inx==[]) then
     
    //! ie = mtlb_i(ie,inx,ie(inx)+2^(l+1)) may be replaced by ie(inx) = ie(inx)+2^(l+1)
    //!   if ie is not a  vector
    //!   or if ie and ie(inx)+2^(l+1) are both row or column vectors
    ie = mtlb_i(ie,inx,ie(inx)+2^(l+1))
     
    //! je = mtlb_i(je,inx,je(inx)+2^(l+1)) may be replaced by je(inx) = je(inx)+2^(l+1)
    //!   if je is not a  vector
    //!   or if je and je(inx)+2^(l+1) are both row or column vectors
    je = mtlb_i(je,inx,je(inx)+2^(l+1))
  end
end
i = ie;
j = je;
 
// 
// Copyright (c) 1993. David L. Donoho
// 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
