function [pkt]=PackShiftCoeff(path,opkt,c,renorm)
pkt=[];
[nargout,nargin] = argn(0)
// PackShiftCoeff --  stuff shifted coefficients into packet table
//  Usage
//    TIWT = PackShiftCoeff(path,oTI,c,renorm)
//  Inputs
//    path     tree selecting circulant shift
//    oTI      translation invariant transform table (e.g. from FWT_TI)
//    c        coefficients at circulant shift
//    renorm   optional; if =1, scale coefficients by 2^d factor
//  Outputs
//    TIWT     new translation invariant table with coefficients in
//             specified path filled in from c
// 
//  Description
//    Fill the packet table coefficients specified by the shift path
//    with the contents of c.
// 
//  See Also
//    UnpackShiftCoeff, BestShift
// 
 
if nargin<4 then
  renorm = 0;
end
 
pkt = opkt;
[n,D1] = size(pkt);
D = D1-1;
J = log(n)/log(2);
L = J-D;
// 
if renorm then
  for d = 1:D
     
    //!! Unknown function dyad ,the original calling sequence is used
     
    //!! Unknown function dyad ,the original calling sequence is used
     
    //! mtlb_e(c,dyad(J-d)) may be replaced by c(dyad(J-d))
    //!    c(dyad(J-d)) if c is a vector,
    //!    c(dyad(J-d)).' if c is a matrix.
     
    //! c = mtlb_i(c,dyad(J-d),mtlb_e(c,dyad(J-d)) .* (2^d)) may be replaced by c(dyad(J-d)) = mtlb_e(c,dyad(J-d)) .* (2^d)
    //!   if c is not a  vector
    //!   or if c and mtlb_e(c,dyad(J-d)) .* (2^d) are both row or column vectors
    c = mtlb_i(c,dyad(J-d),mtlb_e(c,dyad(J-d)) .* (2^d))
  end
   
  //! c = mtlb_i(c,1:2^L,c(1:2^L) .* (2^D)) may be replaced by c(1:2^L) = c(1:2^L) .* (2^D)
  //!   if c is not a  vector
  //!   or if c and c(1:2^L) .* (2^D) are both row or column vectors
  c = mtlb_i(c,1:2^L,c(1:2^L) .* (2^D))
end
// 
dptr = 0;
bptr = 0;
// 
while dptr<D1 then
   
  //!! Unknown function node ,the original calling sequence is used
   
  //! mtlb_e(path,node(dptr,bptr)) may be replaced by path(node(dptr,bptr))
  //!    path(node(dptr,bptr)) if path is a vector,
  //!    path(node(dptr,bptr)).' if path is a matrix.
  dir = mtlb_e(path,node(dptr,bptr));
  if dptr<D then
    dptr = dptr+1;
    bptr = 2*bptr+dir;
    //disp([dptr bptr])
    //disp([size(packet(dptr,bptr,n)), size(c(dyad(J-dptr)))])
     
    //!! Unknown function packet ,the original calling sequence is used
     
    //!! Unknown function dyad ,the original calling sequence is used
     
    //! mtlb_e(c,dyad(J-dptr)) may be replaced by c(dyad(J-dptr))
    //!    c(dyad(J-dptr)) if c is a vector,
    //!    c(dyad(J-dptr)).' if c is a matrix.
    pkt(packet(dptr,bptr,n),dptr+1) = mtlb_e(c,dyad(J-dptr))';
  else
     
    //!! Unknown function packet ,the original calling sequence is used
    pkt(packet(dptr,bptr,n),1) = c(1:2^L)';
    dptr = dptr+1;
  end
end
 
// 
// Copyright (c) 1995. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
