function []=PlotColumns(%matrix,starting,ABS,GlobalScale,par)
[nargout,nargin] = argn(0)
// PlotColumns -- Plot each Column of input matrix
//  Usage
//    PlotColumns(matrix,starting,ABS,GlobalScale);
//  Inputs
//    matrix   input matrix
//    starting   starting position of figures, 1 or 2
//    ABS        take absolute value[1] or not[0]
//    GlobalScale if use global scale[1] or not[0], default = 0;
//  Side Effects
//    generate a figure with plot for each column
//  Description
//    Utility function;
//  Algorithm
//     
//  Examples
//    test = rand(1024,5) - .5;
//    clf; PlotColumns(test)  
//    starting = 2; 
//    clf; PlotColumns(test,starting)
//    ABS = 1;
//    clf; PlotColumns(test,starting,ABS)
//    GlobalScale = 1;
//    clf; PlotColumns(test,starting,ABS,GlobalScale)
//  See Also
//    DisplayDWT.m 
//  References
//    
if nargin<5 then
  par = 0;
end
if nargin<4 then
  GlobalScale = 0;
end
 
if nargin<3 then
  ABS = 0;
end
 
if nargin<2 then
  starting = 1;
end
 
if ABS~=0 then
  %matrix = abs(%matrix);
end
 
 
//! mtlb_min(%matrix) may be replaced by 
//!   min(%matrix) if %matrixis a vector
//!   min(%matrix,'r') if %matrixis a matrix
 
//! mtlb_min(mtlb_min(%matrix)) may be replaced by 
//!   min(mtlb_min(%matrix)) if mtlb_min(%matrix)is a vector
//!   min(mtlb_min(%matrix),'r') if mtlb_min(%matrix)is a matrix
MIN = mtlb_min(mtlb_min(%matrix));
 
//!  mtlb_max(%matrix) may be replaced by 
//!     max(%matrix) if %matrixis a vector
//!     max(%matrix,'r') if %matrixis a matrix
 
//!  mtlb_max(mtlb_max(%matrix)) may be replaced by 
//!     max(mtlb_max(%matrix)) if mtlb_max(%matrix)is a vector
//!     max(mtlb_max(%matrix),'r') if mtlb_max(%matrix)is a matrix
MAX = mtlb_max(mtlb_max(%matrix));
 
[nrows,ncols] = size(%matrix);
nfigures = ncols+starting-1+par;
leftshift = nrows ./ 15;
for i = 0:ncols-1
  %v1$2 = int((i+starting-1)/1);%v1$1 = i+starting-1-1*%v1$2
  xsetech([%v1$1/1,%v1$2/nfigures,1/1,1/nfigures]);
  mtlb_plot(%matrix(:,i+1));
  mtlb_hold('on');
  mtlb_plot(zeros(nrows,1));
  mtlb_hold('off');
  st = mtlb_sprintf('2^%d',i+1);
  if GlobalScale then
     
    //!! Unknown function axis ,the original calling sequence is used
    axis([1,nrows,MIN,MAX]);
  else
     
    //! mtlb_min(%matrix(:,i+1)) may be replaced by 
    //!   min(%matrix(:,i+1)) if %matrix(:,i+1)is a vector
    //!   min(%matrix(:,i+1),'r') if %matrix(:,i+1)is a matrix
     
    //!  mtlb_max(%matrix(:,i+1)) may be replaced by 
    //!     max(%matrix(:,i+1)) if %matrix(:,i+1)is a vector
    //!     max(%matrix(:,i+1),'r') if %matrix(:,i+1)is a matrix
     
    //!! Unknown function axis ,the original calling sequence is used
    axis([1,nrows,mtlb_min(%matrix(:,i+1)),mtlb_max(%matrix(:,i+1))]);
  end
   
  //!! Unknown function axis ,the original calling sequence is used
  axis('off');
  xstring(-leftshift,0,st);
end
 
 
// 
// Copyright (c) 1996. Xiaoming Huo
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
