function [m]=BlockMedian(P,interval,method)
m=[];
[nargout,nargin] = argn(0)
// BlockMedian -- Compute median of a polynomial over an interval
//  Usage
//    m = BlockMedian(P, interval)
//  Inputs
//    P         Polynomial, 
//              p(x) = P(1) x^(n-1) + P(2) x^(n-2) x + ... + P(n)
//    interval  2-vector, end points of a finite interval
//  Outputs
//    m         median(P|interval)
//    
 
if nargin<3 then
  method = 'bisection';
end
 
a = interval(1);
b = interval(2);
 
//! unknown arg type, using mtlb_length 
deg = mtlb_length(P)-1;
 
// calculate the local maxxima of P that lie within [a,b]
peaks = ZeroX(polyder(P),interval);
 
// Some Simple cases where analytic solution is available
if deg<2|max(size(peaks))==0 then
  m = polyval(P,(a+b)/2);
elseif deg==2 then
  pe = -P(2)/(2*P(1));
  if pe<=(3*a+b)/4|pe>=(a+3*b)/4 then
    m = polyval(P,(a+b)/2);
  elseif (pe>(3*a+b)/4)&(pe<=(a+b)/2) then
    m = polyval(P,pe+(b-a)/4);
  elseif (pe<(a+3*b)/4)&(pe>(a+b)/2) then
    m = polyval(P,pe-(b-a)/4);
  end
   
  // General case where an numerical approach is necessary
else
  if method=='sample' then
    // a easy, but computational expensive, thing to do is to
    // sample P on [a,b] and take sample median
    sam = linspace(a,b,50);
     
    //! mtlb_median(polyval(P,sam)) may be replaced by 
    //!   median(polyval(P,sam)) if polyval(P,sam)is a vector
    //!   median(polyval(P,sam),1) if polyval(P,sam)is a matrix
    m = mtlb_median(polyval(P,sam));
  elseif method=='bisection' then
    // method of bisection: iterative
     
    // initial guess
    EPS = 10^(-6);
    found = 0;
    maxxi = ZeroX(polyder(P),interval);
    maxxi = [a,maxxi,b];
     
    //! mtlb_min(polyval(P,maxxi)) may be replaced by 
    //!   min(polyval(P,maxxi)) if polyval(P,maxxi)is a vector
    //!   min(polyval(P,maxxi),'r') if polyval(P,maxxi)is a matrix
    lo = mtlb_min(polyval(P,maxxi));
     
    //!  mtlb_max(polyval(P,maxxi)) may be replaced by 
    //!     max(polyval(P,maxxi)) if polyval(P,maxxi)is a vector
    //!     max(polyval(P,maxxi),'r') if polyval(P,maxxi)is a matrix
    high = mtlb_max(polyval(P,maxxi));
    m = polyval(P,(a+b)/2);
     
    while found==0 then
      // Find the turn points
      Q = P;
       
      //! Q = mtlb_i(Q,deg+1,Q(deg+1)-m) may be replaced by Q(deg+1) = Q(deg+1)-m
      //!   if Q is not a  vector
      //!   or if Q and Q(deg+1)-m are both row or column vectors
      Q = mtlb_i(Q,deg+1,Q(deg+1)-m)
      tp = ZeroX(Q,interval);
      tp = [a,tp,b];
       
      //! unknown arg type, using mtlb_length 
      len = mtlb_length(tp);
       
      Measure1 = sum(tp(2:2:len)-tp(1:2:len-1));
      Measure2 = sum(tp(3:2:len)-tp(2:2:len-1));
       
      if polyval(P,a)>=m then
        MeasureUp = Measure1;
        MeasureDown = Measure2;
      else
        MeasureUp = Measure2;
        MeasureDown = Measure1;
      end
       
      if MeasureUp>(MeasureDown+EPS) then
        // should raise m
        lo = m;
        m = (m+high)/2;
      elseif MeasureDown>(MeasureUp+EPS) then
        // should lower m
        high = m;
        m = (m+lo)/2;
      else
        found = 1;
      end
    end
  end
end
 
// 
// Copyright (c) 1996. Thomas P.Y. Yu
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
