function [a,b]=polyder(u,v)
a=[];b=[];
[nargout,nargin] = argn(0)
// 
//POLYDER Differentiate polynomial.
//   POLYDER(P) returns the derivative of the polynomial whose
//   coefficients are the elements of vector P.
// 
//   POLYDER(A,B) returns the derivative of polynomial A*B.
// 
//   [Q,D] = POLYDER(B,A) returns the derivative of the
//   polynomial ratio B/A, represented as Q/D.
// 
//   See also CONV, DECONV.
 
//   Charles R. Denham, MathWorks, 1988.
//   Copyright (c) 1984-98 by The MathWorks, Inc.
//   $Revision: 5.6 $  $Date: 1997/11/21 23:40:56 $
 
if nargin<2 then
  v = 1;
end
 
u = u(:).';
v = v(:).';
 
//! unknown arg type, using mtlb_length 
nu = mtlb_length(u);
 
//! unknown arg type, using mtlb_length 
nv = mtlb_length(v);
if nu<2 then
  up = 0;
else
  up = u(1:nu-1) .* (nu-1:-1:1);
end
if nv<2 then
  vp = 0;
else
  vp = v(1:nv-1) .* (nv-1:-1:1);
end
a1 = convol(up,v);
a2 = convol(u,vp);
i = max(size(a1));
j = max(size(a2));
z = zeros(1,abs(i-j));
if i>j then
  a2 = [z,a2];
elseif i<j then
  a1 = [z,a1];
end
if nargout<2 then
  a = a1+a2;
else
  a = a1-a2;
end
f = matrix(find(a~=0),1,-1);
if ~(f==[]) then
  a = a(f(1):$);
else
  a = 0;
end
b = convol(v,v);
f = matrix(find(b~=0),1,-1);
 
