function [y,delta]=polyval(p,x,S)
y=[];delta=[];
[nargout,nargin] = argn(0)
// 
//POLYVAL Evaluate polynomial.
//   Y = POLYVAL(P,X), when P is a vector of length N+1 whose elements
//   are the coefficients of a polynomial, is the value of the
//   polynomial evaluated at X.
// 
//       Y = P(1)*X^N + P(2)*X^(N-1) + ... + P(N)*X + P(N+1)
// 
//   If X is a matrix or vector, the polynomial is evaluated at all
//   points in X.  See also POLYVALM for evaluation in a matrix sense.
// 
//   [Y,DELTA] = POLYVAL(P,X,S) uses the optional output structure
//   generated by POLYFIT to generate error estimates, Y +/- delta.
//   If the errors in the data input to POLYFIT are independent normal
//   with constant variance, Y +/- DELTA contains at least 50% of the
//   predictions.
// 
//   See also POLYFIT, POLYVALM.
 
//   Polynomial evaluation p(x) using Horner's method%'
 
//   J.N. Little 4-26-86
//   Revised 3-9-88 JNL, 5-5-93 BAJ
//   Copyright (c) 1984-98 by The MathWorks, Inc.
//   $Revision: 5.10 $  $Date: 1997/11/21 23:40:58 $
 
[m,n] = size(x);
 
//! unknown arg type, using mtlb_length 
nc = mtlb_length(p);
infs = matrix(find(isinf(x)),1,-1);
 
//! unknown arg type, using mtlb_length 
sinfs = sign(x(infs)).^mtlb_length(p) .* x(infs);
 
if ((m+n)==2)&(nargin<3) then
  // Make it scream for scalar x.  Polynomial evaluation can be
  // implemented as a recursive digital filter.
  y = mtlb_filter(1,[1,-x],p);
  y = y(nc);
  return
   
end
 
// Do general case where X is an array
y = zeros(m,n);
for i = 1:nc
  y = x .* y+p(i);
end
 
//if (nargin>2)&(nargout>1) then
  x = x(:);
   
  // Extract parameters from S
   
  //!! Unknown function isstruct ,the original calling sequence is used
//  if isstruct(S) then
    // Use output structure from polyfit.
//    R = S('R');
//    df = S('df');
//    normr = S('normr');
//  else
    // Use output matrix from previous versions of polyfit.
    [ms,ns] = size(S);
    if ms~=(ns+2)|nc~=ns then
      error('S matrix must be n+2-by-n where n = length(p)');
    end
    R = S(1:nc,1:nc);
    df = S(nc+1,1);
    normr = S(nc+2,1);
//  end
   
  // Construct Vandermonde matrix.
   
  //! unknown arg type, using mtlb_length 
  V(:,nc) = ones(mtlb_length(x),1);
  for j = nc-1:-1:1
    V(:,j) = x .* V(:,j+1);
  end
   
  // S is a structure containing three elements: the Cholesky factor of the
  // Vandermonde matrix, the degrees of freedom and the norm of the residuals.
  E = V/R;
  if nc==1 then
    e = sqrt(1+E .* E);
  else
     
    //! mtlb_sum((E .* E)') may be replaced by 
    //!     sum((E .* E)') if (E .* E)'is a vector
    //!     sum((E .* E)',1) if (E .* E)'is a matrix
    e = sqrt(1+mtlb_sum((E .* E)')');
  end
  if df==0 then
    disp('Warning: zero degrees of freedom implies infinite error bounds.');
     
    //!! Unknown function repmat ,the original calling sequence is used
    delta = matrix(%inf,size(e));
  else
    delta = normr/sqrt(df)*e;
  end
  delta = matrix(delta,m,n);
//end
 
 
//! y = mtlb_i(y,infs,sinfs) may be replaced by y(infs) = sinfs
//!   if y is not a  vector
//!   or if y and sinfs are both row or column vectors
y = mtlb_i(y,infs,sinfs)
