function []=PlotMRA_MT(wc,L,scal,D,Title)
[nargout,nargin] = argn(0)
// PlotMRA_MT -- Multi-Resolution Display of 1-d Median Transform
//  Usage
//    PlotMRA_MT(wc,L,scal,D,[Tilte])
//  Inputs
//    wc    1-d median transform
//    L     level of coarsest scale
//    scal  scale factor [0 ==> autoscale]
//    D     degree of polynomial used in median interpolation, 0 or 2.
// 
//  Side Effects
//    A depiction of the multi-resolution decomposition
//    of the signal, as in S. Mallat.
// 
//  See Also
//    FMIPT, IMIPT
// 
 
wc = ShapeAsRow(wc);
if scal==0 then
  scal = 1/max(abs(wc));
end
 
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(wc)/2;
J = round(log(n)/log(3));
// 
LockAxes([0,1,-J-1,-L+1]);
t = (0.5:n-0.5)/n;
 
Pj = IMIPT(wc,L,D);
w = wc;
for j = J:-1:L+1
  // form P_{j-1}
   
  //! unknown arg type, using mtlb_length 
  w(triad(j)) = zeros(1,mtlb_length(triad(j)))
  Pjm1 = IMIPT(w,L,D);
  // form Q_j = P_j - P_{j-1}
  Qj = Pj-Pjm1;
   
  // Display
   
  //! unknown arg type, using mtlb_length 
  if (mtlb_length(scal)>1)&(~(type(scal)==10)) then
    mtlb_plot(t,-j+scal(J-j+1) .* Qj);
  elseif (type(scal)==10)&(scal=='Level') then
    mtlb_plot(t,-j+Qj/max(abs(Qj)));
  else
    mtlb_plot(t,-j+scal .* Qj);
  end
   
  // P_j <-- P_{j-1}
  Pj = Pjm1;
end
// 
w = zeros(1,2*n);
w(1:3^L) = wc(1:3^L)
x = IMIPT(w,L,D);
 
//! unknown arg type, using mtlb_length 
if (mtlb_length(scal)>1)&(~(type(scal)==10)) then
   
  //! mtlb_e(scal,J-L+1) may be replaced by scal(J-L+1)
  //!    scal(J-L+1) if scal is a vector,
  //!    scal(J-L+1).' if scal is a matrix.
  mtlb_plot(t,-L+mtlb_e(scal,J-L+1)*x);
elseif (type(scal)==10)&(scal=='Level') then
  mtlb_plot(t,-L+x/max(abs(x)));
else
  mtlb_plot(t,-L+scal .* x);
end
// 
xtitle(' ','t',' ');
xtitle(' ',' ','Triad');
 
if nargin<5 then
  Title = 'Nonlinear MRA';
end
xtitle(Title,' ',' ');
UnlockAxes();
// 
// Copyright (c) 1996. David L. Donoho and Thomas P.Y. Yu
//     
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
