function [c]=QuasiDCT(x,dir)
c=[];
// QuasiDCT -- Nearly Discrete Cosine Transform of Type I.
//   Usage
//    c = QuasiDCT(x,dir)
//  Inputs
//    x     signal of dyadic length
//    dir   string direction indicator 'f' forward ; 'i' inverse 
//  Outputs
//    c     discrete cosine transform, type I, of x
// 
// See Also
//    CoarseMeyerCoeff, CoarseMeyerProj
 
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(x)-1;
 
// Modifications of signal and sampling of transform are
// different for forward and inverse Meyer wavelet transforms.
 
if dir=='f' then
   
  //! x = mtlb_i(x,1,x(1)/sqrt(2)) may be replaced by x(1) = x(1)/sqrt(2)
  //!   if x is not a  vector
  //!   or if x and x(1)/sqrt(2) are both row or column vectors
  x = mtlb_i(x,1,x(1)/sqrt(2))
   
  //! x = mtlb_i(x,n+1,x(n+1)/sqrt(2)) may be replaced by x(n+1) = x(n+1)/sqrt(2)
  //!   if x is not a  vector
  //!   or if x and x(n+1)/sqrt(2) are both row or column vectors
  x = mtlb_i(x,n+1,x(n+1)/sqrt(2))
  rx = matrix([x;zeros(1,n+1)],1,2*n+2);
  y = [rx,zeros(1,2*n-2)];
  w = real(fft(y,-1));
  c = sqrt(2/n)*w(1:2:n+1);
  c(1) = c(1)/sqrt(2)
   
elseif dir=='i' then
   
  //! x = mtlb_i(x,1,x(1)/sqrt(2)) may be replaced by x(1) = x(1)/sqrt(2)
  //!   if x is not a  vector
  //!   or if x and x(1)/sqrt(2) are both row or column vectors
  x = mtlb_i(x,1,x(1)/sqrt(2))
  rx = matrix([x;zeros(1,n+1)],1,2*(n+1));
  y = rx;
   
  //! mtlb_fft(y) may be replaced by 
  //!      fft(y,-1) if yis a vector
  w = real(mtlb_fft(y));
  c = sqrt(2/(n+1))*w(1:n+2);
  c(1) = c(1)/sqrt(2)
  c(n+2) = c(n+2)/sqrt(2)
end
 
// 
//  Prepared for the thesis of Eric Kolaczyk, Stanford University, 1994
//  Copyright (c) Eric Kolaczyk, 1994.
// 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
