function [nu]=WindowMeyer(xi,deg)
nu=[];
// WindowMeyer -- auxiliary window function for Meyer wavelets.
//  Usage
//    nu = WindowMeyer(xi,deg)
//  Inputs
//    xi     abscissa values for window evaluation
//    deg    degree of the polynomial defining Nu on [0,1]
//           1 <= deg <= 3
//  Outputs
//    nu     polynomial of degree 'deg' if x in [0,1]
//           1 if x > 1 and 0 if x < 0.
//  See Also
//    UnfoldMeyer, FoldMeyer
// 
if deg==0 then
  nu = xi;
else
  if deg==1 then
    nu = xi.^2 .* (3-2 .* xi);
  else
    if deg==2 then
      nu = xi.^3 .* (10-15 .* xi+6 .* (xi.^2));
    else
      if deg==3 then
        nu = xi.^4 .* (35-84 .* xi+70 .* (xi.^2)-20 .* (xi.^3));
      end
    end
  end
end
ix0 = matrix(find(xi<=0),1,-1);
if max(size(ix0))>0 then
  //size(ix0),
   
  //! nu = mtlb_i(nu,ix0,zeros(1,max(size(ix0)))) may be replaced by nu(ix0) = zeros(1,max(size(ix0)))
  //!   if nu is not a  vector
  //!   or if nu and zeros(1,max(size(ix0))) are both row or column vectors
  nu = mtlb_i(nu,ix0,zeros(1,max(size(ix0))))
end
ix1 = matrix(find(xi>=1),1,-1);
if max(size(ix1))>0 then
   
  //! nu = mtlb_i(nu,ix1,ones(1,max(size(ix1)))) may be replaced by nu(ix1) = ones(1,max(size(ix1)))
  //!   if nu is not a  vector
  //!   or if nu and ones(1,max(size(ix1))) are both row or column vectors
  nu = mtlb_i(nu,ix1,ones(1,max(size(ix1))))
end
 
// 
//  Prepared for the thesis of Eric Kolaczyk, Stanford University, 1994
//  Copyright (c) Eric Kolaczyk, 1994.
// 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
