function []=DisplayMultiRes(wc,L,scal,qmf,%type)
// DisplayMultiRes -- Multi-Resolution Mesh Display of 1-d Wavelet Transform
//  Usage
//    DisplayMultiRes(wc,L,scal,qmf,type)
//  Inputs
//    wc    1-d wavelet transform
//    L     level of coarsest scale
//    scal  scale factor [0 ==> autoscale]
//    qmf   quadrature mirror filter used to make wc
//    type  'Mesh','Contour','Image'
// 
//  Side Effects
//    A depiction of the multi-resolution decomposition
//    of signal, as in S. Mallat.
// 
//  See Also
//    PlotWaveCoeff, FWT_PO, IWT_PO, MakeONFilter
// 
 
//!! Unknown function ShapeAsRow ,the original calling sequence is used
wavecoef = ShapeAsRow(wc);
if scal==0 then
   
  //!  mtlb_max(abs(wavecoef)) may be replaced by 
  //!     max(abs(wavecoef)) if abs(wavecoef)is a vector
  //!     max(abs(wavecoef),'r') if abs(wavecoef)is a matrix
  scal = 1/mtlb_max(abs(wavecoef));
end
 
 
//!! Unknown function dyadlength ,the original calling sequence is used
[n,J] = dyadlength(wavecoef);
num_levels = J-L+1;
display_array = zeros(num_levels,n);
// 
count = 1;
w = zeros(1,n);
w(1:2^L) = wavecoef(1:2^L)
display_array(count,:) = scal .* IWT_PO(w,L,qmf);
 
for j = J-1:-1:L
  count = count+1;
  w = zeros(1,n);
   
  //!! Unknown function dyad ,the original calling sequence is used
   
  //!! Unknown function dyad ,the original calling sequence is used
   
  //! mtlb_e(wavecoef,dyad(j)) may be replaced by wavecoef(dyad(j))
  //!    wavecoef(dyad(j)) if wavecoef is a vector,
  //!    wavecoef(dyad(j)).' if wavecoef is a matrix.
  %v1 = mtlb_e(wavecoef,dyad(j))
  w(1,dyad(j)) = %v1(:).';
  display_array(count,:) = scal .* IWT_PO(w,j,qmf);
end
// 
if %type=='Mesh' then
  mtlb_mesh(display_array);
elseif %type=='Contour' then
  contour2d(1:size(display_array,1),1:size(display_array,2),display_array);
elseif %type=='Image' then
   
  //!! Unknown function pcolor ,the original calling sequence is used
  pcolor(display_array);
   
  //!! Unknown function shading ,the original calling sequence is used
  shading('interp');
  xset('colormap',graycolormap(32));
else
  disp('Only allowed types are Mesh, Contour and Image');
end
// 
// xlabel('t'); ylabel('Dyad');
// title('Multi-Resolution Decomposition');
 
// 
// Copyright (c) 1993. David L. Donoho and Jeffrey D. Scargle
//     
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
