function []=DisplayWaveCoeff(wc,L,scal,%type,num_use)
[nargout,nargin] = argn(0)
// DisplayWaveCoeff -- Display wavelet coefficients
//  Usage
//    DisplayWaveCoeff(wc,L,scal,type[,num_use])
//  Inputs
//    wc        1-d wavelet transform
//    L         level of coarsest scale
//    scal      scale factor [0 ==> autoscale]
//    type      'Mesh','Contour','Image'
//    num_use   for Contour only, number of contours to plot (def. 8)
// 
//  Side Effects
//    A display of wavelet coefficients (coarsest level NOT
//    included) by level and position.
// 
//  See Also
//    PlotMultiRes, FWT_PO, IWT_PO, PlotSpikes
// 
 
if nargin<5 then
  num_use = 8;
end
 
 
//!! Unknown function ShapeAsRow ,the original calling sequence is used
wavecoef = ShapeAsRow(wc);
 
//!! Unknown function dyadlength ,the original calling sequence is used
[n,J] = dyadlength(wavecoef);
if scal==0 then
  scal = 1/max(abs(wavecoef(2^L+1:n)));
end
// 
num_levels = J-L;
display_array = zeros(num_levels,n);
 
// 
for j = J-1:-1:L
   
  //!! Unknown function dyad ,the original calling sequence is used
   
  //! mtlb_e(wavecoef,dyad(j)) may be replaced by wavecoef(dyad(j))
  //!    wavecoef(dyad(j)) if wavecoef is a vector,
  //!    wavecoef(dyad(j)).' if wavecoef is a matrix.
  temp = mtlb_e(wavecoef,dyad(j)) .* scal;
  num_copies = n/(2^j);
  temp = ones(num_copies,1)*temp;
  [aa,bb] = size(temp);
  temp = matrix(temp,1,aa*bb);
  display_array(j,:) = temp;
end
// 
log_thresh = 0.01;
 
 
//!  mtlb_max(display_array) may be replaced by 
//!     max(display_array) if display_arrayis a vector
//!     max(display_array,'r') if display_arrayis a matrix
 
//!  mtlb_max(mtlb_max(display_array)) may be replaced by 
//!     max(mtlb_max(display_array)) if mtlb_max(display_array)is a vector
//!     max(mtlb_max(display_array),'r') if mtlb_max(display_array)is a matrix
d_max = mtlb_max(mtlb_max(display_array));
 
//! mtlb_min(display_array) may be replaced by 
//!   min(display_array) if display_arrayis a vector
//!   min(display_array,'r') if display_arrayis a matrix
 
//! mtlb_min(mtlb_min(display_array)) may be replaced by 
//!   min(mtlb_min(display_array)) if mtlb_min(display_array)is a vector
//!   min(mtlb_min(display_array),'r') if mtlb_min(display_array)is a matrix
d_min = mtlb_min(mtlb_min(display_array));
display_array = 255*(display_array-d_min)/(d_max-d_min);
//   d_max = max(max( display_array ));
//   d_min = min(min( display_array ));
//   disp(['Max: ' num2str(d_max) '; Min: ' num2str(d_min)])
display_array = abs(display_array($:-1:1,:));
 
if %type=='Mesh' then
  mtlb_mesh(display_array);
   
  //!! Unknown function shading ,the original calling sequence is used
  shading('flat');
  xset('colormap',graycolormap(32));
elseif %type=='Contour' then
  contour2d(1:size(display_array,1),1:size(display_array,2),display_array,num_use);
elseif %type=='Image' then
   
  //!! Unknown function pcolor ,the original calling sequence is used
  pcolor(display_array);
   
  //!! Unknown function shading ,the original calling sequence is used
  shading('flat');
  xset('colormap',graycolormap(32));
else
  disp('Only allowed types are Mesh, Contour and Image');
end
 
// 
// Copyright (c) 1993. David L. Donoho and Jeffrey D. Scargle
//     
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
