function [wcoef]=FWT_CDJV(x,L,N)
wcoef=[];
// FWT_CDJV -- Forward Wavelet Transform (boundary-corrected)
//  Usage
//    wc = FWT_CDJV(x,L,N)
//  Inputs
//    y    1-d signal, length(x) = 2^J
//    L    Level of V_0;  L << J
//    N    Degree of Daubechies Filters
// 
//  Description
//    CDJV have developed an algorithm for wavelets on the interval which
//    preserves the orthogonality, vanishing moments, smoothness, and compact
//    support of Daubechies wavelets on the line.
// 
//    The algorithm for wavelets on the interval of CDJV involves four objects
//    not present in the usual periodized algorithm: right edge filters, left
//    edge filters, and pre- and post- conditioning operators.
// 
//    These objects are supplied by appropriate requests to MakeCDJVFilter.
// 
//    To reconstruct use CDJV_IWT.
// 
//  See Also
//    IWT_CDJV, FWT_PO, IWT_PO, MakeCDJVFilter
// 
 
//!! Unknown function MakeCDJVFilter ,the original calling sequence is used
[HPF,LHPEF,RHPEF] = MakeCDJVFilter('HighPass',N);
 
//!! Unknown function MakeCDJVFilter ,the original calling sequence is used
[LPF,LLPEF,RLPEF] = MakeCDJVFilter('LowPass',N);
 
//!! Unknown function MakeCDJVFilter ,the original calling sequence is used
[LPREMAT,RPREMAT] = MakeCDJVFilter('PreCondition',N);
// 
 
//!! Unknown function ShapeAsRow ,the original calling sequence is used
y = ShapeAsRow(x);
[n,J] = dyadlength(y);
wcoef = zeros(1,n);
// 
beta = y;
 
//! beta = mtlb_i(beta,1:N,beta(1:N)*LPREMAT') may be replaced by beta(1:N) = beta(1:N)*LPREMAT'
//!   if beta is not a  vector
//!   or if beta and beta(1:N)*LPREMAT' are both row or column vectors
beta = mtlb_i(beta,1:N,beta(1:N)*LPREMAT')
 
//! beta = mtlb_i(beta,n:-1:n-N+1,beta(n:-1:n-N+1)*RPREMAT') may be replaced by beta(n:-1:n-N+1) = beta(n:-1:n-N+1)*RPREMAT'
//!   if beta is not a  vector
//!   or if beta and beta(n:-1:n-N+1)*RPREMAT' are both row or column vectors
beta = mtlb_i(beta,n:-1:n-N+1,beta(n:-1:n-N+1)*RPREMAT')
for j = J-1:-1:L
  alfa = CDJVDyadDown(beta,HPF,LHPEF,RHPEF);
  wcoef(dyad(j)) = alfa
  beta = CDJVDyadDown(beta,LPF,LLPEF,RLPEF);
end
wcoef(1,1:2^L) = beta(:).';
// 
 
//!! Unknown function ShapeLike ,the original calling sequence is used
wcoef = ShapeLike(wcoef,x);
 
// 
// Copyright (c) 1993. David L. Donoho.
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
