function [wave2d]=Make2dWavelet(j,k1,k2,ep,Family,par,n)
wave2d=[];
[nargout,nargin] = argn(0)
// Make2dWavelet -- Make 2-d Wavelet
//  Usage
//    wave2d = Make2dWavelet(j,k1,k2,ep[,Family,par,n])
//  Inputs
//    j        resolution level
//    k1,k2    spatial indices
//    ep       spatial orientation
//             ep = 0:  Father(x)Father(y)
//                  1:  Mother(x)Father(y)
//                  2:  Father(x)Mother(y)
//                  3:  Mother(x)Mother(y)
//    Family   string: 'Haar', 'Daubechies', 'Coiflet', 'Symmlet', 'Meyer'
//             Default: 'Symmlet', Nearly-Symmetric ON Wavelet
//    par      integer parameter to MakeONFilter, etc.
//             When Default 'Symmlet' active, default 8.
//    n        image side length (dyadic)
//  Outputs
//    wave2d   2-d image, the wavelet
// 
 
if nargin<7 then
  n = 2^(j+3);
end
if nargin<5 then
  Family = 'Symmlet';
  par = 8;
end
// 
if bool2s(Family=='Haar')+bool2s(Family=='Daubechies')+bool2s(Family=='Coiflet')+bool2s(Family=='Symmlet') then
   
  //!! Unknown function MakeONFilter ,the original calling sequence is used
  qmf = MakeONFilter(Family,par);
  w = zeros(n,n);
   
  //!! Unknown function quad2ix ,the original calling sequence is used
  [kx,ky] = quad2ix(j,k1,k2,ep);
  w(kx,ky) = 1;
  wave2d = IWT2_PO(w,j,qmf);
  // 
elseif Family=='Meyer' then
  w = zeros(n,n);
   
  //!! Unknown function quad2ix ,the original calling sequence is used
   
  //! w = mtlb_i(w,quad2ix(j,k1,k2,ep),1) may be replaced by w(quad2ix(j,k1,k2,ep)) = 1
  //!   if w is not a  vector
  //!   or if w and 1 are both row or column vectors
  w = mtlb_i(w,quad2ix(j,k1,k2,ep),1)
   
  //!! Unknown function IWT2_YM ,the original calling sequence is used
  wave2d = IWT2_YM(w,j,par);
end
 
// 
// Copyright (c) 1995. Jonathan Buckheit
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
