function [cp,btree]=CPTour(Format,x,D,titlestr)
cp=[];btree=[];
// CPTour -- Cosine packet decomposition & Best Basis analysis
//  Usage
//    [cp, btree] = CPTour(Format,x,D,title)
//  Inputs
//    Format   string: 'S' for sequential, 'P' for panel  
//    x        1-d signal to analyze by Cosine Packets
//    D        maximum depth of dyadic subdivision of time domain
//    title    name of signal [optional]
//  Outputs 
//    cp       packet table (see CPAnalysis)
//    btree    basis tree of best time-frequency basis
// 
//  Description
//    The format string controls whether all four displays
//    are drawn as subplots in one figure, or whether they are 
//    drawn one-after-the-other on the same figure.
// 
//    The global PREFERIMAGEGRAPHICS controls whether the phase
//    portrait is done using ``image'' graphics (if ==1 ) or ``plot''
//    graphics (if == 0).
// 
//  Side Effects
//    plot of Cosine packet Table
//    tree plot, best basis
//    phase plot, best basis
//    printout, entropy, best basis
// 
//  See Also
//    CPAnalysis, BestBasis, PlotPhasePlane, PlotBasisTree
// 
global('PREFERIMAGEGRAPHICS');
 
//! Not enough information using mtlb_exist instead of exists
if ~mtlb_exist('PREFERIMAGEGRAPHICS') then
  PREFERIMAGEGRAPHICS = 0;
end
// 
cp = CPAnalysis(x,D,'Sine');
// 
mtlb_clf();
if Format(1)=='P' then
  xsetech([0/2,0/2,1/2,1/2]);
end
// 
 
//!! Unknown function PlotPacketTable ,the original calling sequence is used
PlotPacketTable(cp);
signaltitle = 'Cosine Packet Analysis '+titlestr;
xtitle(signaltitle,' ',' ');
xtitle(' ',' ','Split Level');
xtitle(' ','Time[Frequency]',' ');
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
stree = CalcStatTree(cp,'Entropy');
 
//!! Unknown function BestBasis ,the original calling sequence is used
[btree,vtree] = BestBasis(stree,D);
// 
if Format(1)=='P' then
  xsetech([1/2,0/2,1/2,1/2]);
end
// 
signaltitle = ' CP Best Basis; '+titlestr;
 
//!! Unknown function PlotBasisTree ,the original calling sequence is used
PlotBasisTree(btree,D,stree,signaltitle);
xtitle(' ','Splits of Time Domain',' ');
xtitle(' ',' ','Entropy Drop');
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
if Format(1)=='P' then
  xsetech([0/2,1/2,1/2,1/2]);
end
// 
// PlotPhaseTiling('CP',btree,cp,signaltitle);
 
//!! Unknown function UnpackBasisCoeff ,the original calling sequence is used
cpcoef = UnpackBasisCoeff(btree,cp);
 
//!! Unknown function PlotCompressNumbers ,the original calling sequence is used
PlotCompressNumbers(cpcoef,signaltitle);
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
if Format(1)=='P' then
  xsetech([1/2,1/2,1/2,1/2]);
end
// 
if PREFERIMAGEGRAPHICS then
   
  //!! Unknown function ImagePhasePlane ,the original calling sequence is used
  ImagePhasePlane('CP',btree,cp,signaltitle);
else
   
  //!! Unknown function PlotPhasePlane ,the original calling sequence is used
  PlotPhasePlane('CP',btree,cp,signaltitle);
end
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
 
// 
// Copyright (c) 1993. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
