function [maxheight,cost]=CalcTreeHeight(stree,D)
maxheight=[];cost=[];
// CalcTreeHeight -- Measure the total height of a stat-tree
//  Usage
//    [maxheight, cost] = CalcTreeHeight(stree,D)
//  Inputs
//    stree       stat tree (e.g. generated by CalcStatTree)
//    D           maximum depth of search
//  Outputs
//    maxheight   Height of the tree, assigning to each branch a length
//                equal to the entropy drop between parent and child
//    cost        Tree of entropy drops associated with various splits
// 
//  Description
//    This is a utility used by PlotBasisTree to set scale for plotting
//    It is not intended for other use.
// 
//  See Also
//    CalcStatTree, PlotBasisTree
// 
 
%v=size(stree)
cost = zeros(%v(1),%v(2));
value = stree;
// prune, bottom-UpSample, left-right scan
for d = D-1:-1:0
  for b = 0:2^d-1
     
    //! mtlb_e(stree,node(d,b)) may be replaced by stree(node(d,b))
    //!    stree(node(d,b)) if stree is a vector,
    //!    stree(node(d,b)).' if stree is a matrix.
    vparent = mtlb_e(stree,node(d,b));
     
    //! mtlb_e(value,node(d+1,2*b)) may be replaced by value(node(d+1,2*b))
    //!    value(node(d+1,2*b)) if value is a vector,
    //!    value(node(d+1,2*b)).' if value is a matrix.
     
    //! mtlb_e(value,node(d+1,2*b+1)) may be replaced by value(node(d+1,2*b+1))
    //!    value(node(d+1,2*b+1)) if value is a vector,
    //!    value(node(d+1,2*b+1)).' if value is a matrix.
    vchild = mtlb_e(value,node(d+1,2*b))+mtlb_e(value,node(d+1,2*b+1));
    if vparent<vchild then
       
      //! value = mtlb_i(value,node(d,b),vparent) may be replaced by value(node(d,b)) = vparent
      //!   if value is not a  vector
      //!   or if value and vparent are both row or column vectors
      value = mtlb_i(value,node(d,b),vparent)
       
      //! cost = mtlb_i(cost,node(d,b),0) may be replaced by cost(node(d,b)) = 0
      //!   if cost is not a  vector
      //!   or if cost and 0 are both row or column vectors
      cost = mtlb_i(cost,node(d,b),0)
    else
       
      //! value = mtlb_i(value,node(d,b),vchild) may be replaced by value(node(d,b)) = vchild
      //!   if value is not a  vector
      //!   or if value and vchild are both row or column vectors
      value = mtlb_i(value,node(d,b),vchild)
       
      //! cost = mtlb_i(cost,node(d,b),vparent-vchild) may be replaced by cost(node(d,b)) = vparent-vchild
      //!   if cost is not a  vector
      //!   or if cost and vparent-vchild are both row or column vectors
      cost = mtlb_i(cost,node(d,b),vparent-vchild)
    end
  end
end
height = cost .* 0;
// prune, bottom-UpSample, left-right scan
for d = D-1:-1:0
  for b = 0:2^d-1
     
    //! mtlb_e(cost,node(d,b)) may be replaced by cost(node(d,b))
    //!    cost(node(d,b)) if cost is a vector,
    //!    cost(node(d,b)).' if cost is a matrix.
    delta = mtlb_e(cost,node(d,b));
    if delta==0 then
       
      //! height = mtlb_i(height,node(d,b),0) may be replaced by height(node(d,b)) = 0
      //!   if height is not a  vector
      //!   or if height and 0 are both row or column vectors
      height = mtlb_i(height,node(d,b),0)
    else
       
      //! mtlb_e(height,node(d+1,2*b)) may be replaced by height(node(d+1,2*b))
      //!    height(node(d+1,2*b)) if height is a vector,
      //!    height(node(d+1,2*b)).' if height is a matrix.
       
      //! mtlb_e(height,node(d+1,2*b+1)) may be replaced by height(node(d+1,2*b+1))
      //!    height(node(d+1,2*b+1)) if height is a vector,
      //!    height(node(d+1,2*b+1)).' if height is a matrix.
       
      //! height = mtlb_i(height,node(d,b),delta+max(mtlb_e(height,node(d+1,2*b)),mtlb_e(height,node(d+1,2*b+1)))) may be replaced by height(node(d,b)) = delta+max(mtlb_e(height,node(d+1,2*b)),mtlb_e(height,node(d+1,2*b+1)))
      //!   if height is not a  vector
      //!   or if height and delta+max(mtlb_e(height,node(d+1,2*b)),mtlb_e(height,node(d+1,2*b+1))) are both row or column vectors
      height = mtlb_i(height,node(d,b),delta+max(mtlb_e(height,node(d+1,2*b)),mtlb_e(height,node(d+1,2*b+1))))
    end
  end
end
maxheight = height(1);
 
// 
// Copyright (c) 1993. David L. Donoho
//    
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
