function [minlev]=CompareStdBases(tree,D)
minlev=[];
// CompareStdBases -- Calculate entropy of some standard bases
//  Usage
//    bestlev = CompareStdBases(stree,D)
//  Inputs
//    stree      stat tree (e.g. returned by CalcStatTree)
//    D          maximum level to search
//  Outputs
//    bestlev    best single level of basis
// 
//  Side Effects
//    Prints out statistics of all single-level bases of packet
//    table, prints out statistics of wavelet basis.
// 
//  See Also
//    ImagePhaseVarious, PlotPhaseVarious
// 
 
entlevel = zeros(1,D+1);
mtlb_fprintf('entropy by level\n');
entmin = 10.^6;
minlev = 0;
for d = 0:D
  loindex = node(d,0);
  hiindex = node(d,2^d-1);
  entlevel(d+1) = sum(tree(loindex:hiindex))
  mtlb_fprintf('%g  %g \n',d,entlevel(d+1));
  if entlevel(d+1)<entmin then
    minlev = d;
    entmin = entlevel(d+1);
  end
end
mtlb_fprintf('best level = %g; entropy = %g \n',minlev,entmin);
 
//! mtlb_e(tree,node(D,0)) may be replaced by tree(node(D,0))
//!    tree(node(D,0)) if tree is a vector,
//!    tree(node(D,0)).' if tree is a matrix.
entwave = mtlb_e(tree,node(D,0));
for d = 1:D
   
  //! mtlb_e(tree,node(d,1)) may be replaced by tree(node(d,1))
  //!    tree(node(d,1)) if tree is a vector,
  //!    tree(node(d,1)).' if tree is a matrix.
  entwave = entwave+mtlb_e(tree,node(d,1));
end
mtlb_fprintf('wavelet entropy= %g \n',entwave);
 
//    
// Copyright (c) 1993. David L. Donoho
//     
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
