function []=ImagePacketPhase(TFtype,pkt,titlestr,nTFR,qmf)
[nargout,nargin] = argn(0)
// ImagePacketPhase -- Partition phase space by rectangular blocks
//  Usage
//    ImagePacketPhase(TFtype,pkt[,titlestr,nTFR,qmf]) 
//  Inputs
//    TFtype     string: type of TF-packets used ('WP','CP')
//    pkt        wavelet or cosine packet table
//    titlestr   signal name (optional)
//    nTFR       number of x-points in phaseplane image (optional)
//    qmf        qmf for calculating WP phase plane location (optional)
// 
//  Side Effects
//    An image plot with gray rectangles based on assigning mass
//    proportional to coefficient to square of Heisenberg rectangle.
// 
//  See Also
//    ImageGaborPhase, ImageWavePhase, PlotPhasePlane
// 
 
if nargin<5 then
  // Is Wavelet Packet Phase Plane
  Corrected = 0;
  //    Position-Corrected?
else
  Corrected = 1;
end
 
if nargin<4 then
  nTFR = 256;
end
 
if nargin<3 then
  titlestr = ' ';
end
[n,L] = size(pkt);
D = L-1;
// 
TFPlane = zeros(nTFR,nTFR);
 
//!  mtlb_max(abs(pkt)) may be replaced by 
//!     max(abs(pkt)) if abs(pkt)is a vector
//!     max(abs(pkt),'r') if abs(pkt)is a matrix
 
//!  mtlb_max(mtlb_max(abs(pkt))) may be replaced by 
//!     max(mtlb_max(abs(pkt))) if mtlb_max(abs(pkt))is a vector
//!     max(mtlb_max(abs(pkt)),'r') if mtlb_max(abs(pkt))is a matrix
MMax = mtlb_max(mtlb_max(abs(pkt)))^2;
for d = 0:D
  for b = 0:2^d-1
    ylo = b/(2^d);
    yhi = (b+1)/(2^d);
    nylo = 1+floor(nTFR*ylo);
    nyhi = min(1+floor(nTFR*yhi),nTFR);
    coeffs = pkt(packet(d,b,n),d+1).^2;
     
    //! mtlb_sum(coeffs) may be replaced by 
    //!     sum(coeffs) if coeffsis a vector
    //!     sum(coeffs,1) if coeffsis a matrix
    CEnerg = mtlb_sum(coeffs);
    nbox = n ./ (2^d);
    // = length(coeffs);
    if CEnerg>0.0001*MMax then
      if TFtype=='CP' then
        for j = 0:nbox-1
          if coeffs(1+j)>0 then
            nxlo = 1+floor(nTFR*j/nbox);
            nxhi = min(1+floor(nTFR*(j+1)/nbox),nTFR);
            TFPlane(nxlo:nxhi,nylo:nyhi) = TFPlane(nxlo:nxhi,nylo:nyhi)+coeffs(1+j);
          end
        end
      else
        if Corrected then
          pos = CalcWPLocation(d,b,0,qmf,n);
        else
          pos = 0;
        end
        for j = 0:nbox-1
          %v5$1 = pos/n*nbox+j
          jpos = %v5$1-fix(%v5$1./nbox).*nbox;
          if coeffs(1+j)>0 then
            nxlo = 1+floor(nTFR*jpos/nbox);
            nxhi = min(1+floor(nTFR*(jpos+1)/nbox),nTFR);
            TFPlane(nylo:nyhi,nxlo:nxhi) = TFPlane(nylo:nyhi,nxlo:nxhi)+coeffs(1+j);
          end
        end
      end
    end
  end
end
// 
 
//!  mtlb_max(TFPlane) may be replaced by 
//!     max(TFPlane) if TFPlaneis a vector
//!     max(TFPlane,'r') if TFPlaneis a matrix
 
//!  mtlb_max(mtlb_max(TFPlane)) may be replaced by 
//!     max(mtlb_max(TFPlane)) if mtlb_max(TFPlane)is a vector
//!     max(mtlb_max(TFPlane),'r') if mtlb_max(TFPlane)is a matrix
TFMax = mtlb_max(mtlb_max(TFPlane));
TFPlane = TFPlane .* (63 ./ TFMax);
 
//!! Unknown function image ,the original calling sequence is used
image(linspace(0,1,nTFR),linspace(0,1,nTFR),TFPlane);
 
//!! Unknown function axis ,the original calling sequence is used
axis('xy');
 
//!! Unknown function axis ,the original calling sequence is used
axis([0,1,0,1]);
xset('colormap',1-graycolormap(64));
titlestr = 'Phase plane: '+titlestr;
xtitle(titlestr,' ',' ');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
 
// 
// Copyright (c) 1994. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
