function []=PlotPhaseTiling(%type,basis,pkt,titlestr,plotchar)
[nargout,nargin] = argn(0)
// PlotPhaseTiling -- partition phase space by rectangular blocks
//  Usage
//    PlotPhaseTiling(type,btree,pkt[,titlestr,plotchar]) 
//  Inputs
//    type       string 'WP' or 'CP' naming type of TF analysis
//    btree      basis tree (e.g. as produced by BestBasis)
//    pkt        wavelet or cosine packet table
//    titlestr   signal name (optional)
//    plotchar   plotting character (optional)
// 
//  Side Effects
//    A plot with rectangles based on recursive dyadic partitioning
//    of y axis according to splits in basis tree.
//  See Also
//    CPTour, WPTour
// 
if nargin<5 then
  plotchar = '-';
end
 
if nargin<4 then
  titlestr = ' ';
end
 
[n,L] = size(pkt);
// 
//  Initialize tree traversal stack
// 
dstack = zeros(1,2^L);
bstack = zeros(1,2^L);
k = 1;
dstack(k) = 0
bstack(k) = 0
// 
ss = norm(pkt(:,1));
// 
// Initialize plotting window
// 
 
//!! Unknown function LockAxes ,the original calling sequence is used
LockAxes([0,1,0,1]);
titlestr = 'Tiling of Phase plane: '+titlestr;
xtitle(titlestr,' ',' ');
// 
while k>0 then
  d = dstack(k);
  b = bstack(k);
  k = k-1;
   
  //! mtlb_e(basis,node(d,b)) may be replaced by basis(node(d,b))
  //!    basis(node(d,b)) if basis is a vector,
  //!    basis(node(d,b)).' if basis is a matrix.
  if mtlb_e(basis,node(d,b))==0 then
    // terminal node
    ylo = b/(2^d);
    yhi = (b+1)/(2^d);
    nbox = n ./ (2^d);
    // = length(coeffs);
    if %type=='WP' then
      mtlb_plot([0,1],[ylo,ylo],plotchar);
      mtlb_plot([0,1],[yhi,yhi],plotchar);
      for j = 0:nbox-1
        mtlb_plot([j/nbox,j/nbox],[ylo,yhi],plotchar);
        mtlb_plot([(j+1)/nbox,(j+1)/nbox],[ylo,yhi],plotchar);
      end
    else
      mtlb_plot([ylo,ylo],[0,1],plotchar);
      mtlb_plot([yhi,yhi],[0,1],plotchar);
      for j = 0:nbox-1
        mtlb_plot([ylo,yhi],[j/nbox,j/nbox],plotchar);
        mtlb_plot([ylo,yhi],[(j+1)/nbox,(j+1)/nbox],plotchar);
      end
    end
  else
    k = k+1;
    dstack(k) = d+1
    bstack(k) = 2*b
    k = k+1;
    dstack(k) = d+1
    bstack(k) = 2*b+1
  end
end
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
 
//!! Unknown function UnlockAxes ,the original calling sequence is used
UnlockAxes();
// 
// Copyright (c) 1993. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
