function []=PlotPhaseVarious(wp,wp_stree,cp,cp_stree,titlestr)
// PlotPhaseVarious -- Show several different phase plane images
//  Usage
//    PlotPhaseComparison(wp,wp_stree,cp,cp_stree,titlestr)
//  Inputs  
//    wp          Wavelet Packet table
//    wp_stree    Wavelet Packet Stat tree
//    cp          Cosine Packet table
//    cp_stree    Cosine Packet Stat tree
//    titlestr    title for plot
// 
//  Side Effects
//    For both Wavelet Packets and Cosine Packets:
//      phase plot, best level
//      phase plot, best basis
//      printout, entropies best level, best basis
// 
[n,L] = size(wp);
D = L-1;
// 
bestwplevel = CompareStdBases(wp_stree,D);
header = mtlb_sprintf('WP Best Level(=%g) ',bestwplevel);
signaltitle = header+titlestr;
xsetech([0/2,0/2,1/2,1/2]);
PlotGaborPhase('WP',wp,bestwplevel,signaltitle);
// 
xsetech([1/2,0/2,1/2,1/2]);
bwptree = BestBasis(wp_stree,D);
signaltitle = 'WP Best Basis; '+titlestr;
 
//!! Unknown function PlotPhasePlane ,the original calling sequence is used
PlotPhasePlane('WP',bwptree,wp,signaltitle);
// 
[n,L] = size(cp);
D = L-1;
// 
bestcplevel = CompareStdBases(cp_stree,D);
header = mtlb_sprintf('CP Best Level(=%g) ',bestcplevel);
signaltitle = header+titlestr;
xsetech([0/2,1/2,1/2,1/2]);
PlotGaborPhase('CP',cp,bestcplevel,signaltitle);
// 
xsetech([1/2,1/2,1/2,1/2]);
signaltitle = 'CP Best Basis; '+titlestr;
bcptree = BestBasis(cp_stree,D);
 
//!! Unknown function PlotPhasePlane ,the original calling sequence is used
PlotPhasePlane('CP',bcptree,cp,signaltitle);
 
// 
// Copyright (c) 1993. David L. Donoho
//     
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
