function [wp,btree]=WPTour(Format,x,D,qmf,titlestr)
wp=[];btree=[];
// WPTour -- Wavelet packet decomposition & Best Basis analysis
//  Usage
//    [wp, btree] = WPTour(Format,x,D,qmf,title)
//  Inputs  
//    Format  string: 'S' for sequential display of four figures
//                    'P' for four-panel display  
//    x       1-d signal to analyze by Wavelet Packets
//    D       fineness of frequency splitting
//    qmf     quadrature mirror filter (e.g. Coiflet c3)
//    title   name of signal
//  Outputs
//    wp      Wavelet packet table (see WPAnalysis)
//    btree   basis tree of best time-frequency basis
// 
//  Description
//    The format string controls whether all four displays
//    are drawn as subplots in one figure, or whether they are
//    drawn one-after-the-other on the same figure
// 
//    The global PREFERIMAGEGRAPHICS controls whether the phase
//    portrait is done using ``image'' graphics (if =1) or ``plot''
//    graphics (if =0).
// 
//  Side Effects
//    plot of Wavelet packet Table
//    tree plot, best basis
//    phase plot, best basis
//    printout, entropy, best basis
// 
//  See Also
//    WPAnalysis, BestBasis, PlotPhasePlane, PlotBasisTree
// 
 
global('PREFERIMAGEGRAPHICS');
 
//! Not enough information using mtlb_exist instead of exists
if ~mtlb_exist('PREFERIMAGEGRAPHICS') then
  PREFERIMAGEGRAPHICS = 0;
end
// 
wp = WPAnalysis(x,D,qmf);
// 
mtlb_clf();
if Format(1)=='P' then
  xsetech([0/2,0/2,1/2,1/2]);
end
// 
 
//!! Unknown function PlotPacketTable ,the original calling sequence is used
PlotPacketTable(wp);
signaltitle = 'Wavelet Packet Analysis '+titlestr;
xtitle(signaltitle,' ',' ');
xtitle(' ',' ','Split Level');
xtitle(' ','Frequency[Time]',' ');
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
stree = CalcStatTree(wp,'Entropy');
[btree,vtree] = BestBasis(stree,D);
// 
if Format(1)=='P' then
  xsetech([1/2,0/2,1/2,1/2]);
end
// 
signaltitle = ' WP Best Basis; '+titlestr;
PlotBasisTree(btree,D,stree,signaltitle);
xtitle(' ','Frequency Domain Splits',' ');
xtitle(' ',' ','Entropy Gain');
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
if Format(1)=='P' then
  xsetech([0/2,1/2,1/2,1/2]);
end
// 
// PlotPhaseTiling('WP',btree,wp,signaltitle);
wpcoef = UnpackBasisCoeff(btree,wp);
PlotCompressNumbers(wpcoef,signaltitle);
 
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
if Format(1)=='P' then
  xsetech([1/2,1/2,1/2,1/2]);
end
// 
if PREFERIMAGEGRAPHICS then
  ImagePhasePlane('WP',btree,wp,signaltitle,256,qmf);
else
  PlotPhasePlane('WP',btree,wp,signaltitle);
end
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
 
// 
// Copyright (c) 1993. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
