function [bb,stats,coef]=CP2Tour(img,MaxDeep,titlestr)
bb=[];stats=[];coef=[];
[nargout,nargin] = argn(0)
// CP2dTour -- Cosine Packet Analysis in Adaptively Chosen Basis
//  Usage
//    [bb,stats,coef] = CP2dTour(img,MaxDeep,titlestr)
//  Inputs
//    img        2-d image; size n by n, n dyadic
//    MaxDeep    integer; limit on max depth of tree in best basis search
//    titlestr   string; name of signal
//  Outputs
//    bb         basis quadtree of best basis
//    stats      stat quadtree of best basis
//    coef       coefficients in best basis
// 
//  Description
//    Perform an adaptive cosine packet analysis on the given image,
//    selecting the best basis and then plotting the CP coefficients
//    for this basis along with the image overlaid by its 2-d partition.
// 
global('WLVERBOSE');
if nargin<3 then
  titlestr = '';
end
// 
 
//! mtlb_mean(img) may be replaced by 
//!   mean(img) if imgis a vector
//!   mean(img,1) if imgis a matrix
img0 = img-mean(mtlb_mean(img));
stats = Calc2dStatTree('CP',img0,MaxDeep,'Sine','l^p',1);
bb = Best2dBasis(stats,MaxDeep);
 
//!! Unknown function FPT2_CP ,the original calling sequence is used
coef = FPT2_CP(bb,img,MaxDeep);
 
if WLVERBOSE=='Yes' then
   
  //!! Unknown function AutoImage ,the original calling sequence is used
  AutoImage(abs(coef));
   
  //!! Unknown function axis ,the original calling sequence is used
  ax = axis();
  mtlb_hold('on');
   
  //!! Unknown function Plot2dPartition ,the original calling sequence is used
  Plot2dPartition(bb,'y',ax,MaxDeep);
  xtitle(mtlb_sprintf('Coeff in CP BestBasis; %s',titlestr),' ',' ');
  mtlb_hold('off');
   
  //!! drawnow ignored
  // drawnow
   ;
   
end
// 
xset('window',max(winsid()+1))
max(winsid());
 
//!! Unknown function AutoImage ,the original calling sequence is used
AutoImage(img);
 
//!! Unknown function axis ,the original calling sequence is used
ax = axis();
mtlb_hold('on');
 
//!! Unknown function Plot2dPartition ,the original calling sequence is used
Plot2dPartition(bb,'y',ax,MaxDeep);
xtitle(mtlb_sprintf('Image & Best CP Partition; %s',titlestr),' ',' ');
 
//!! drawnow ignored
// drawnow
 ;
mtlb_hold('off');
 
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
