function [heights]=Calc2dTreeHeight(qtree,D)
heights=[];
// Calc2dTreeHeight -- Measure the total height of a stat-quad-tree
//  Usage
//    heights = Calc2dTreeHeight(stree,D)
//  Inputs
//    stree     stat tree (e.g. generated by CalcStatTree)
//    D         maximum depth of search
//  Outputs
//    heights   Lengths of branches, assigning each branch
//              length equal to the entropy drop between parent & child
// 
//  Description
//    This is a utility used by Plot2dBasisTree to set scale for plotting.
//    It is not intended for other use.
// 
//  See Also
//        Calc2dStatTree, Plot2dBasisTree
// 
 
%v=size(qtree)
heights = zeros(%v(1),%v(2));
value = qtree;
// prune, bottom-up, left-right scan
for d = D-1:-1:0
  for bx = 0:2^d-1
    for by = 0:2^d-1
       
       
      //! mtlb_e(qtree,qnode(d,bx,by)) may be replaced by qtree(qnode(d,bx,by))
      //!    qtree(qnode(d,bx,by)) if qtree is a vector,
      //!    qtree(qnode(d,bx,by)).' if qtree is a matrix.
      vparent = mtlb_e(qtree,qnode(d,bx,by));
       
      //! mtlb_e(value,qnode(d+1,2*bx,2*by)) may be replaced by value(qnode(d+1,2*bx,2*by))
      //!    value(qnode(d+1,2*bx,2*by)) if value is a vector,
      //!    value(qnode(d+1,2*bx,2*by)).' if value is a matrix.
       
      //! mtlb_e(value,qnode(d+1,2*bx+1,2*by)) may be replaced by value(qnode(d+1,2*bx+1,2*by))
      //!    value(qnode(d+1,2*bx+1,2*by)) if value is a vector,
      //!    value(qnode(d+1,2*bx+1,2*by)).' if value is a matrix.
       
      //! mtlb_e(value,qnode(d+1,2*bx,2*by+1)) may be replaced by value(qnode(d+1,2*bx,2*by+1))
      //!    value(qnode(d+1,2*bx,2*by+1)) if value is a vector,
      //!    value(qnode(d+1,2*bx,2*by+1)).' if value is a matrix.
       
      //! mtlb_e(value,qnode(d+1,2*bx+1,2*by+1)) may be replaced by value(qnode(d+1,2*bx+1,2*by+1))
      //!    value(qnode(d+1,2*bx+1,2*by+1)) if value is a vector,
      //!    value(qnode(d+1,2*bx+1,2*by+1)).' if value is a matrix.
      vchild = mtlb_e(value,qnode(d+1,2*bx,2*by))+mtlb_e(value,qnode(d+1,2*bx+1,2*by))+mtlb_e(value,qnode(d+1,2*bx,2*by+1))+mtlb_e(value,qnode(d+1,2*bx+1,2*by+1));
       
      if vparent<vchild then
         
        //! heights = mtlb_i(heights,qnode(d,bx,by),0) may be replaced by heights(qnode(d,bx,by)) = 0
        //!   if heights is not a  vector
        //!   or if heights and 0 are both row or column vectors
        heights = mtlb_i(heights,qnode(d,bx,by),0)
      else
         
        //! heights = mtlb_i(heights,qnode(d,bx,by),vparent-vchild) may be replaced by heights(qnode(d,bx,by)) = vparent-vchild
        //!   if heights is not a  vector
        //!   or if heights and vparent-vchild are both row or column vectors
        heights = mtlb_i(heights,qnode(d,bx,by),vparent-vchild)
      end
       
    end
  end
end
 
// 
// Copyright (c) 1993. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
