function [Ent]=CalcEntropy(object,Entropy,par)
Ent=[];
// CalcEntropy -- Calculate entropy number of array
//  Usage
//    Ent = CalcEntropy(object,ent[,par])
//  Inputs
//    object   1-d or 2-d object
//    ent      type of entropy to use: options are
//                'Entropy' -- Coifman-Wickerhauser
//                'Log'     -- sum log(|th_i|)
//                'l^p'     -- sum |th_i|^p, 0 < p < 2, p = par
//                'N(eps)'  -- #>= eps, eps = par
//                'Risk'    -- sum min(th_i^2,eps^2), eps=par
//                'Sum'     -- sum th_i
//                'SURE'    -- SURE(Thresholding), thresh = par
//    par      extra parameter, depends on type of entropy
//  Outputs
//    Ent      Entropy of object
// 
//  Description
//    It is traditional to normalize the object to norm 1 before
//    calling this routine.  This routine does NO pre-scaling.
// 
//  See Also
//    Calc2dStatTree
//    
 
if Entropy=='Entropy' then
  p = object(:).^2;
  Ent = -sum(sum(p .* log(%eps+p)));
elseif Entropy=='Log' then
  p = abs(object(:));
  Ent = sum(log(%eps+p));
elseif Entropy=='l^p' then
  // par = p = exponent
  p = abs(object(:));
   
  //! mtlb_sum(p.^par) may be replaced by 
  //!     sum(p.^par) if p.^paris a vector
  //!     sum(p.^par,1) if p.^paris a matrix
  Ent = mtlb_sum(p.^par);
elseif Entropy=='N(eps)' then
  // par = eps
  p = abs(object(:));
  Ent = sum(p>par);
elseif Entropy=='Risk' then
  p = object(:).^2;
   
  //! mtlb_sum(min(p,par^2)) may be replaced by 
  //!     sum(min(p,par^2)) if min(p,par^2)is a vector
  //!     sum(min(p,par^2),1) if min(p,par^2)is a matrix
  Ent = mtlb_sum(min(p,par^2));
elseif Entropy=='Sum' then
  p = object(:);
  Ent = sum(p);
elseif Entropy=='SURE' then
  tt = par^2;
  // par = threshold
   
  //! unknown arg type, using mtlb_length 
  dim = mtlb_length(object(:));
  p = object(:).^2;
  ngt = sum(p>tt);
  nlt = dim-ngt;
  slt = sum(p .* bool2s(p<=tt));
  Ent = dim-2*nlt+tt*ngt+slt;
else
  disp('in CalcEntropy: unknown Entropy request');
  mtlb_fprintf('Request=<<%s>>\n',Entropy);
  disp('I only know how to do:');
  disp(' Entropy, Log, l^p, N(eps), Risk, SURE ');
end
 
// 
// Copyright (c) 1993-5, Jonathan Buckheit and David Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
