function [coef]=Unpack2dBasisCoeff(basis,pkt2)
coef=[];
// Unpack2dBasisCoeff -- Extract basis coefficients from 2-d packet table
//  Usage
//    coef = Unpack2dBasisCoeff(basis,pkt2)
//  Inputs
//    basis    Quad Tree selecting 2-d packet basis
//    pkt2     n^2 by D, 2-d packet table
//  Outputs
//    coef     2-d packet coefficients in given basis
// 
[n2,J] = size(pkt2);
D = J-1;
n = floor(sqrt(n2+0.5)+0.5);
coef = zeros(n,n);
// 
// initialize tree traversal stack
// 
stack = zeros(3,4*(D+1)+1);
k = 1;
stack(:,k) = [0,0,0]';
// d, bx, by
// 
while k>0 then
   
  // pop stack
  d = stack(1,k);
  bx = stack(2,k);
  by = stack(3,k);
  k = k-1;
  //  fprintf('d bx by'); disp([d bx by])
   
   
  //! mtlb_e(basis,qnode(d,bx,by)) may be replaced by basis(qnode(d,bx,by))
  //!    basis(qnode(d,bx,by)) if basis is a vector,
  //!    basis(qnode(d,bx,by)).' if basis is a matrix.
  if mtlb_e(basis,qnode(d,bx,by))==0 then
    // terminal node
     
    out = matrix(pkt2(:,d+1),n,n);
    [lox,hix,loy,hiy] = quadbounds(d,bx,by,n);
    //fprintf('[lox hix loy hiy]'); disp([lox hix loy hiy])
     
    quad = out(lox:hix,loy:hiy);
    coef(lox:hix,loy:hiy) = quad;
     
  else
    // nonterminal node
     
    // push stack
    k = k+1;
    stack(:,k) = [d+1,2*bx,2*by]';
    k = k+1;
    stack(:,k) = [d+1,2*bx+1,2*by]';
    k = k+1;
    stack(:,k) = [d+1,2*bx,2*by+1]';
    k = k+1;
    stack(:,k) = [d+1,2*bx+1,2*by+1]';
     
  end
end
 
// 
// Copyright (c) 1994. Jonathan Buckheit
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
