function [xhat]=RigorThresh(y)
xhat=[];
// RigorThresh -- Adaptive Threshold Selection using SURE
// Usage
//   xhat = RigorThresh(y)
// Inputs
//   y     Noisy Data with Std. Deviation = 1
// Outputs
//   xhat  Estimate of mean vector
// Notes
//   Using Principle of Stein's Unbiased Risk Estimate
//   Variant with Rigorous Proof
// 
// See: Donoho, D.L. and Johnstone, I.M. ``Adapting
//   to Unknown Smoothness by Wavelet Shrinkage''
 
 
//!! Unknown function dyadlength ,the original calling sequence is used
[n,J] = dyadlength(y);
magic = sqrt(2*log(n));
 
// pretest statistic
eta = (norm(y).^2-n)/n;
crit = (J^1.5)/sqrt(n);
 
if eta<crit then
   
  // failed pretest -- use sqrt(2 log(n))
   
  //!! Unknown function SoftThresh ,the original calling sequence is used
  xhat = SoftThresh(y,magic);
   
else
   
  // Construct random subsets of size n/2 each
  %v1=size(y)
  xhat = rand(%v1(1),%v1(2),'u');
   
  //! next test may  probably be simplified
  if min(size(xhat))==1 then 
    v=-sort(-xhat)
  else
    v=-sort(-xhat,'r')
  end
  v = v;
   
  //! mtlb_e(v,n/2) may be replaced by v(n/2)
  //!    v(n/2) if v is a vector,
  //!    v(n/2).' if v is a matrix.
  I = xhat>mtlb_e(v,n/2);
  Ip = ~I;
   
  // Apply SURE to each half
   
  //! mtlb_e(y,I) may be replaced by y(I)
  //!    y(I) if y is a vector,
  //!    y(I).' if y is a matrix.
   
  //!! Unknown function ValSUREThresh ,the original calling sequence is used
  T = min(ValSUREThresh(mtlb_e(y,I)),magic);
   
  //! mtlb_e(y,Ip) may be replaced by y(Ip)
  //!    y(Ip) if y is a vector,
  //!    y(Ip).' if y is a matrix.
   
  //!! Unknown function ValSUREThresh ,the original calling sequence is used
  Tp = min(ValSUREThresh(mtlb_e(y,Ip)),magic);
  xhat = y;
   
  // Threshold from one half is applied to other
   
  //! mtlb_e(y,I) may be replaced by y(I)
  //!    y(I) if y is a vector,
  //!    y(I).' if y is a matrix.
   
  //!! Unknown function SoftThresh ,the original calling sequence is used
   
  //! xhat = mtlb_i(xhat,I,SoftThresh(mtlb_e(y,I),Tp)) may be replaced by xhat(I) = SoftThresh(mtlb_e(y,I),Tp)
  //!   if xhat is not a  vector
  //!   or if xhat and SoftThresh(mtlb_e(y,I),Tp) are both row or column vectors
  xhat = mtlb_i(xhat,I,SoftThresh(mtlb_e(y,I),Tp))
   
  //! mtlb_e(y,Ip) may be replaced by y(Ip)
  //!    y(Ip) if y is a vector,
  //!    y(Ip).' if y is a matrix.
   
  //!! Unknown function SoftThresh ,the original calling sequence is used
   
  //! xhat = mtlb_i(xhat,Ip,SoftThresh(mtlb_e(y,Ip),T)) may be replaced by xhat(Ip) = SoftThresh(mtlb_e(y,Ip),T)
  //!   if xhat is not a  vector
  //!   or if xhat and SoftThresh(mtlb_e(y,Ip),T) are both row or column vectors
  xhat = mtlb_i(xhat,Ip,SoftThresh(mtlb_e(y,Ip),T))
   
end
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
