function [atomic,resid]=CPPursuitTour(Format,x,D,bell,natom,titlestr)
atomic=[];resid=[];
// CPPursuitTour -- Cosine Packet atomic decomposition
//  Usage
//    [cp, btree] = CPPursuitTour(Format,x,D,ball [,natom,title])
//  Inputs  
//    Format   string: 'S' for sequential display of four figures
//                     'P' for four-panel display  
//    x        1-d signal to analyze by Wavelet Packets
//    D        fineness of time domain splitting
//    bell     bellname (e.g. 'Sine')
//    natom    maximum number of atoms to extract by Matching Pursuit
//    title    name of signal
//  Outputs 
//    atomic   atom list,  cosine packet dictionary (see CPPursuit)
//    resid    residual
// 
//  Description
//    The format string controls whether all four displays
//    are drawn as subplots in one figure, or whether they are 
//    drawn one-after-the-other on the same figure
// 
//    The global PREFERIMAGEGRAPHICS controls whether the phase
//    portrait is done using ``image'' graphics (if =1) or ``plot''
//    graphics (if =0).
// 
//  Side Effects
//    plot of Cosine Packet Synthesis Table
//    plot of Cosine Packet Residuals Table
//    plot of Compression Numbers
//    plot of phase plane
// 
//  See Also
//    WPAnalysis, BestBasis, PlotPhasePlane, PlotBasisTree
// 
 
global('PREFERIMAGEGRAPHICS');
 
//! Not enough information using mtlb_exist instead of exists
if ~mtlb_exist('PREFERIMAGEGRAPHICS') then
  PREFERIMAGEGRAPHICS = 0;
end
// 
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(x);
[atomic,resid] = CPPursuit(x,D,bell,natom,0.001,0);
// 
if Format(1)=='P' then
  xsetech([0/2,0/2,1/2,1/2]);
end
// 
signaltitle = 'MP; CP Dict.; '+titlestr;
 
//!! Unknown function PlotSynthesisTable ,the original calling sequence is used
PlotSynthesisTable('CP',atomic,n,D,0,signaltitle);
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
// 
if Format(1)=='P' then
  xsetech([1/2,0/2,1/2,1/2]);
end
// 
cp = CPAnalysis(resid,D,bell);
 
//!! Unknown function PlotPacketTable ,the original calling sequence is used
PlotPacketTable(cp);
signaltitle = 'MP Residuals ; CP Dict.; '+titlestr;
xtitle(signaltitle,' ',' ');
xtitle(' ',' ','Split Level');
xtitle(' ','Time[Frequency]',' ');
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
if Format(1)=='P' then
  xsetech([0/2,1/2,1/2,1/2]);
end
// 
 
//! mtlb_sum(x.^2) may be replaced by 
//!     sum(x.^2) if x.^2is a vector
//!     sum(x.^2,1) if x.^2is a matrix
energy = mtlb_sum(x.^2);
compressnumbers = [energy;energy-cumsum(atomic(:,1).^2)];
mtlb_plot(log(compressnumbers));
xtitle(' ','m',' ');
xtitle(' ',' ','log(c_m)');
xtitle('Compression Numbers',' ',' ');
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
if Format(1)=='P' then
  xsetech([1/2,1/2,1/2,1/2]);
end
// 
if PREFERIMAGEGRAPHICS then
   
  //!! Unknown function ImageAtomicPhase ,the original calling sequence is used
  ImageAtomicPhase('CP',atomic,n,titlestr);
else
   
  //!! Unknown function PlotAtomicPhase ,the original calling sequence is used
  PlotAtomicPhase('CP',atomic,n,titlestr);
end
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
// Copyright (c) 1993-1994. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
