function []=ImageAtomicPhase(TFtype,atomlist,n,titlestr,nTFR,qmf)
[nargout,nargin] = argn(0)
// ImageAtomicPhase -- Image time-frequency content of atom list
//  Usage
//    ImageAtomicPhase(TFType,atomlist,n[,titlestr,nTFR,qmf]) 
//  Inputs
//    TFtype     string, specifying type of TF atoms, 'CP' or 'WP' 
//    atomlist   atom list, e.g. as produced by CPPursuit
//    n          signal length
//    titlestr   signal name (optional)
//    nTFR       number of x-points in phaseplane image (optional)
//    qmf        qmf for calculating WP phase plane location (optional)
// 
//  Side Effects
//    Image of Time-Frequency Plane, with shading showing Heisenberg
//    cells of the atoms making a significant contribution.
// 
//  See Also
//    CPPursuit, WPPursuit
// 
if nargin<6 then
  // Is Wavelet Packet Phase Plane
  Corrected = 0;
  //    Position-Corrected?
else
  Corrected = 1;
end
 
if nargin<5 then
  nTFR = 256;
end
if nargin<4 then
  titlestr = ' ';
end
[natom,ncharm] = size(atomlist);
ss = norm(atomlist(:,1));
// 
TFPlane = zeros(nTFR,nTFR);
 
// 
for k = 1:natom
  e = n*(atomlist(k,1) ./ ss^2);
  d = atomlist(k,2);
  b = atomlist(k,3);
  f = atomlist(k,4);
  if Corrected&('WP'==TFtype) then
     
    //!! Unknown function CalcWPLocation ,the original calling sequence is used
    pos = CalcWPLocation(d,b,0,qmf,n);
    nbox = n ./ (2^d);
    %v2$1 = pos/n*nbox+f
    f = %v2$1-fix(%v2$1./nbox).*nbox;
  end
  ylo = b/(2^d);
  yhi = (b+1)/(2^d);
  xlo = f*(2^d)/n;
  xhi = (f+1)*(2^d)/n;
  nylo = 1+floor(nTFR*ylo);
  nyhi = 1+floor(nTFR*yhi);
  nxlo = 1+floor(nTFR*xlo);
  nxhi = 1+floor(nTFR*xhi);
   
  //!! Unknown function WrapAround ,the original calling sequence is used
  xind = WrapAround(nxlo:nxhi,nTFR);
   
  //!! Unknown function WrapAround ,the original calling sequence is used
  yind = WrapAround(nylo:nyhi,nTFR);
   
  if TFtype=='CP' then
    TFPlane(xind,yind) = TFPlane(xind,yind)+e;
  else
    TFPlane(yind,xind) = TFPlane(yind,xind)+e;
  end
end
// 
 
 
//!  mtlb_max(TFPlane) may be replaced by 
//!     max(TFPlane) if TFPlaneis a vector
//!     max(TFPlane,'r') if TFPlaneis a matrix
 
//!  mtlb_max(mtlb_max(TFPlane)) may be replaced by 
//!     max(mtlb_max(TFPlane)) if mtlb_max(TFPlane)is a vector
//!     max(mtlb_max(TFPlane),'r') if mtlb_max(TFPlane)is a matrix
TFMax = mtlb_max(mtlb_max(TFPlane));
TFPlane = TFPlane .* (256 ./ TFMax);
xset('colormap',1-graycolormap(256));
 
//!! Unknown function image ,the original calling sequence is used
image(linspace(0,1,nTFR),linspace(0,1,nTFR),TFPlane);
 
//!! Unknown function axis ,the original calling sequence is used
axis('xy');
 
//!! Unknown function axis ,the original calling sequence is used
axis([0,1,0,1]);
titlestr = 'Phase plane: '+titlestr;
xtitle(titlestr,' ',' ');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
 
// 
// Copyright (c) 1993-1994. David L. Donoho and Shaobing Chen
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
