function []=PlotAtomicPhase(TFType,atomlist,n,titlestr)
[nargout,nargin] = argn(0)
// PlotAtomicPhase -- Plot time-frequency content of atom list
//  Usage
//    PlotAtomicPhase(atomlist,n[,titlestr]) 
//  Inputs
//    TFType       string indicating type of TF atoms: 'CP' or 'WP'   
//    atomlist     atom list, e.g. as produced by CPPursuit or WPPursuit
//    n            signal length
//    titlestr     signal name (optional)
// 
//  Side Effects
//    A plot of Time-Frequency Plane, with rectangles showing Heisenberg
//    cells of the atoms making a significant contribution.
// 
if nargin<4 then
  titlestr = ' ';
end
[natom,ncharm] = size(atomlist);
ss = norm(atomlist(:,1));
// 
 
//!! Unknown function LockAxes ,the original calling sequence is used
LockAxes([0,1,0,1]);
titlestr = 'Phase plane: '+titlestr;
xtitle(titlestr,' ',' ');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
// 
for k = 1:natom
  e = n*(atomlist(k,1) ./ ss^2);
  d = atomlist(k,2);
  b = atomlist(k,3);
  f = atomlist(k,4);
  ylo = b/(2^d);
  yhi = (b+1)/(2^d);
  xlo = f*(2^d)/n;
  xhi = (f+1)*(2^d)/n;
  if TFType=='WP' then
     
    //!! Unknown function DrawHeisenberg ,the original calling sequence is used
    DrawHeisenberg(xlo,xhi,ylo,yhi,e);
  else
     
    //!! Unknown function DrawHeisenberg ,the original calling sequence is used
    DrawHeisenberg(ylo,yhi,xlo,xhi,e);
  end
end
// 
 
//!! Unknown function UnlockAxes ,the original calling sequence is used
UnlockAxes();
// 
// Copyright (c) 1993. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
