function [atomic,resid]=WPMPursuitTour(x,D,qmf,natom,titlestr)
atomic=[];resid=[];
// WPMPursuitTour -- Wavelet Packet atomic decomposition
//  Usage
//    [wp, btree] = WPMPursuitTour(Format,x,D,qmf [,maxits,title])
//  Inputs  
//    x       1-d signal to analyze by Wavelet Packets
//    D       fineness of frequency splitting
//    qmf     quadrature mirror filter (e.g. Coiflet c3)
//    natom   maximum number of atoms to extract by Matching Pursuit
//    title   name of signal
//  Outputs 
//    atomic  atoms list, wavelet packet dictionary (see WPPursuit)
//    resid   residual
// 
// 
//  See Also
//    WPAnalysis, BestBasis, PlotPhasePlane, PlotBasisTree
// 
 
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(x);
[atomic,resid] = WPPursuit(x,D,qmf,natom,0.001,0);
 
signaltitle = 'MP; WP Dict.; '+titlestr;
PlotSynthesisTable('WP',atomic,n,D,0,signaltitle);
// 
wp = WPAnalysis(resid,D,qmf);
PlotPacketTable(wp);
signaltitle = 'MP Residuals ; WP Dict.; '+titlestr;
xtitle(signaltitle,' ',' ');
xtitle(' ',' ','Split Level');
xtitle(' ','Frequency[Time]',' ');
// 
 
//! mtlb_sum(x.^2) may be replaced by 
//!     sum(x.^2) if x.^2is a vector
//!     sum(x.^2,1) if x.^2is a matrix
energy = mtlb_sum(x.^2);
compressnumbers = [energy;energy-cumsum(atomic(:,1).^2)];
mtlb_plot(log(compressnumbers));
xtitle(' ','m',' ');
xtitle(' ',' ','log(c_m)');
xtitle('Compression Numbers',' ',' ');
 
PlotAtomicPhase('WP',atomic,n,titlestr);
 
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
