function [atomic,resid]=WPPursuitTour(Format,x,D,qmf,natom,titlestr)
atomic=[];resid=[];
// WPPursuitTour -- Wavelet Packet atomic decomposition
//  Usage
//    [wp, btree] = WPPursuitTour(Format,x,D,qmf [,maxits,title])
//  Inputs  
//    Format  string: 'S' for sequential display of four figures
//                    'P' for four-panel display  
//    x       1-d signal to analyze by Wavelet Packets
//    D       fineness of frequency splitting
//    qmf     quadrature mirror filter (e.g. Coiflet c3)
//    natom   maximum number of atoms to extract by Matching Pursuit
//    title   name of signal
//  Outputs 
//    atomic  atoms list, wavelet packet dictionary (see WPPursuit)
//    resid   residual
// 
//  Side Effects
//    plot of Wavelet Packet Synthesis Table
//    plot of Wavelet Packet Residuals Table
//    plot of Compression Numbers
//    plot of phase plane
// 
//  Description
//    The format string controls whether all four displays
//    are drawn as subplots in one figure, or whether they are 
//    drawn one-after-the-other on the same figure.
// 
//    The global PREFERIMAGEGRAPHICS controls whether the phase
//    portrait is done using ``image'' graphics (if =1) or ``plot''
//    graphics (if =0).
// 
//  See Also
//    WPAnalysis, BestBasis, PlotPhasePlane, PlotBasisTree
// 
 
global('PREFERIMAGEGRAPHICS');
 
//! Not enough information using mtlb_exist instead of exists
if ~mtlb_exist('PREFERIMAGEGRAPHICS') then
  PREFERIMAGEGRAPHICS = 0;
end
// 
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(x);
[atomic,resid] = WPPursuit(x,D,qmf,natom,0.001,0);
// 
if Format(1)=='P' then
  xsetech([0/2,0/2,1/2,1/2]);
end
// 
signaltitle = 'MP; WP Dict.; '+titlestr;
PlotSynthesisTable('WP',atomic,n,D,0,signaltitle);
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
// 
if Format(1)=='P' then
  xsetech([1/2,0/2,1/2,1/2]);
end
// 
wp = WPAnalysis(resid,D,qmf);
PlotPacketTable(wp);
signaltitle = 'MP Residuals ; WP Dict.; '+titlestr;
xtitle(signaltitle,' ',' ');
xtitle(' ',' ','Split Level');
xtitle(' ','Frequency[Time]',' ');
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
if Format(1)=='P' then
  xsetech([0/2,1/2,1/2,1/2]);
end
// 
 
//! mtlb_sum(x.^2) may be replaced by 
//!     sum(x.^2) if x.^2is a vector
//!     sum(x.^2,1) if x.^2is a matrix
energy = mtlb_sum(x.^2);
compressnumbers = [energy;energy-cumsum(atomic(:,1).^2)];
mtlb_plot(log(compressnumbers));
xtitle(' ','m',' ');
xtitle(' ',' ','log(c_m)');
xtitle('Compression Numbers',' ',' ');
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
// 
if Format(1)=='P' then
  xsetech([1/2,1/2,1/2,1/2]);
end
// 
if PREFERIMAGEGRAPHICS then
  ImageAtomicPhase('WP',atomic,n,titlestr,256,qmf);
else
  PlotAtomicPhase('WP',atomic,n,titlestr);
end
// 
if Format(1)=='S' then
   
  //!! Unknown function HitAnyKey ,the original calling sequence is used
  HitAnyKey();
   
end
 
// 
// Copyright (c) 1993. David L. Donoho
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
