function [cwd]=CohenDist(sig,sigma)
cwd=[];
// CohenDist -- Choi William Distribution
//  Usage
//    cwd = CohenDist(sig,sigma)
//  Inputs
//    sig     1-d signal
//    sigma   Choi William distribution parameter
//  Outputs
//    cwd    complex-valued matrix representing the Choi & William
//           distribution of periodic signal with rows corresponding
//           to frequencies and columns corresponding to times.
// 
//  Side Effects
//    Image Plot of the Choi & William distribution
// 
//  See Also
//    Interpol2
// 
//  References
//    Mallat's book, sections 4.5.3 and 4.5.4
// 
sig = sig(:);
 
//! unknown arg type, using mtlb_length 
N = mtlb_length(sig);
sig = Interpol2(sig);
f = [zeros(2*N,1);sig;zeros(2*N,1)];
ambig = zeros(N,N);
phi = zeros(N,N);
smambig = zeros(N,N);
n = 1:2:2*N-1;
 
for p = 0:N-1
  tplus = 2*N+n+p;
  tminus = 2*N+n-p;
  x = conj(f(tplus)) .* f(tminus);
  ambig(:,p+1) = fft(x,-1);
end
 
i = -N/2-1:N/2-2;
ix = exp(-i.^2 ./ (sigma.^2));
for j = -N/2-1:N/2-2
  phi(:,j+N/2+2) = ix.^((j^2)');
end
 
 
//!! Unknown function fftshift ,the original calling sequence is used
phi = fftshift(phi);
smambig = phi .* ambig;
 
 
//!! Unknown function ifft2 ,the original calling sequence is used
cwd = ifft2(smambig)';
 
abstf = real(cwd(1:N/2,:)) .* bool2s(real(cwd(1:N/2,:))>=zeros(N/2,N));
 
//!  mtlb_max(abstf) may be replaced by 
//!     max(abstf) if abstfis a vector
//!     max(abstf,'r') if abstfis a matrix
 
//!  mtlb_max(mtlb_max(abstf)) may be replaced by 
//!     max(mtlb_max(abstf)) if mtlb_max(abstf)is a vector
//!     max(mtlb_max(abstf),'r') if mtlb_max(abstf)is a matrix
tfmax = mtlb_max(mtlb_max(abstf));
 
//! mtlb_min(abstf) may be replaced by 
//!   min(abstf) if abstfis a vector
//!   min(abstf,'r') if abstfis a matrix
 
//! mtlb_min(mtlb_min(abstf)) may be replaced by 
//!   min(mtlb_min(abstf)) if mtlb_min(abstf)is a vector
//!   min(mtlb_min(abstf),'r') if mtlb_min(abstf)is a matrix
tfmin = mtlb_min(mtlb_min(abstf));
xset('colormap',1-graycolormap(256));
//colormap(hot)
 
//!! Unknown function image ,the original calling sequence is used
image(linspace(0,N,N),linspace(0,N/2,N/2),256*(abstf-tfmin)/(tfmax-tfmin));
 
//!! Unknown function axis ,the original calling sequence is used
axis('xy');
xtitle('',' ',' ');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
 
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
 
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
