function []=Spectrogram()
[nargout,nargin] = argn(0)
// Spectrogram -- Time-Varying Spectrum
//  Usage
//    specgm = Spectrogram(sig,w,m,titl)
//  Inputs
//    sig      1-d signal
//    w        window half-length, default = n/2
//    m        inter-window spacing, default=1
//    titl     Optional Title String Modifier
//  Outputs
//    specgm   spectrogram
// 
//  Side Effects
//    Image Plot of the spectrogram
// 
//  See Also
//    WVDist, WVDist_AF, ImagePhasePlane
// 
// 
 
//!! Unknown variable x ,the original calling sequence is used
sig = x(:);
 
//! mtlb(x) can be replaced by x() or x whether x is an m-file or not
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(mtlb(x));
f = [zeros(n,1);sig;zeros(n,1)];
// 
if nargin<2 then
  w = n/2;
end
if nargin<3 then
  m = 1;
end
if nargin<4 then
  titl = [];
end
// 
nw = floor(n ./ m);
specgm = zeros(w+1,nw);
ix = -w+1:w;
// 
for l = 1:nw
  t = 1+(l-1)*m;
  if (m==1)&((t-fix(t./16).*16)==1) then
    mtlb_fprintf('Spectrogram: t=%i\n',t);
  end
  // 
  tim = n+t+ix;
  seg = f(tim);
  localspec = abs(fft(seg,-1));
  specgm(:,l) = localspec(1:w+1);
end
// 
// 
// Make Spectrogram Display
// 
 
//!  mtlb_max(specgm) may be replaced by 
//!     max(specgm) if specgmis a vector
//!     max(specgm,'r') if specgmis a matrix
 
//!  mtlb_max(mtlb_max(specgm)) may be replaced by 
//!     max(mtlb_max(specgm)) if mtlb_max(specgm)is a vector
//!     max(mtlb_max(specgm),'r') if mtlb_max(specgm)is a matrix
spmax = mtlb_max(mtlb_max(specgm));
 
//! mtlb_min(specgm) may be replaced by 
//!   min(specgm) if specgmis a vector
//!   min(specgm,'r') if specgmis a matrix
 
//! mtlb_min(mtlb_min(specgm)) may be replaced by 
//!   min(mtlb_min(specgm)) if mtlb_min(specgm)is a vector
//!   min(mtlb_min(specgm),'r') if mtlb_min(specgm)is a matrix
spmin = mtlb_min(mtlb_min(specgm));
xset('colormap',1-graycolormap(256));
 
//!! Unknown variable image ,the original calling sequence is used
image(linspace(0,1,n),linspace(0,1,w+1),256*(specgm-spmin)/(spmax-spmin));
 
//!! Unknown variable axis ,the original calling sequence is used
axis('xy');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
// 
 
//!! Unknown variable AppendTitle ,the original calling sequence is used
titl = AppendTitle('Spectrogram',titl);
xtitle(titl,' ',' ');
// 
if nargout==1 then
  specgm = [];
end
// 
// 
// Copyright (c) 1995, David Donoho
// 
// 
// 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
// 
