function [aftf]=TFDist_AF(sig)
aftf=[];
// TFDist_AF -- Alias-Free Generalized Discrete Time-Frequency Distribution
//  Usage
//    aftf = TFDist_AF(sig)
//  Inputs
//    sig     1-d signal of dyadic length n=2^J
//  Outputs
//    aftf    complex-valued matrix representing the alias-free generalized
//            time-frequency distribution of zero-extended signal with rows
//            corresponding to frequencies and columns corresponding to times
// 
//  Side Effects
//    Image Plot of the alias free TF distribution
// 
//  See Also
//   WigDist, AFWigDist, specgram, ImagePhasePlane
// 
//  References
//   Jechang Jeong and William J. Williams,
//   """"Alias-Free Generalized Discrete-Time Time-Frequency Distribution
//   IEEE Transactions on Signal Processing"""", vol. 40, pp. 2757-2765
// 
 
sig = sig(:);
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(sig);
f = [zeros(n,1);sig;zeros(n,1)];
aftf = zeros(n,n);
zerosn = zeros(n,1);
 
for t = 1:n
  x = zerosn;
  for k = 0:n/2-1
    // even indices
    if k==0 then
      x(2*k+1) = f(n+t)*f(n+t)
    else
      ix = -k:k;
      tplus = n+t+k-ix;
      tminus = n+t-k-ix;
      ff = f(tplus) .* f(tminus);
      b = 1/((2*k+1)*0.54+0.46*real((exp(%i*2*%pi*(k+1)/(2*k))-exp(-%i*%pi))/(1-exp(%i*%pi/k))));
      x(2*k+1) = b*(0.54+0.46*cos(2*%pi*ix/(2*k)))*ff
    end
     
    // odd indices
    ix = -k:k+1;
    tplus = n+t+k-ix+1;
    tminus = n+t-k-ix;
    ff = f(tplus) .* f(tminus);
    b = 1/((2*k+2)*0.54+0.46*real((exp(%i*2*%pi*(k+2)/(2*k+1))-exp(-%i*2*%pi*k/(2*k+1)))*exp(-%i*%pi/(2*k+1))/(1-exp(%i*2*%pi/(2*k+1)))));
    x(2*k+2) = b*(0.54+0.46*cos(2*%pi*(ix-0.5)/(2*k+1)))*ff
  end
  //  aftf(:,t) = 2 * real(fft(x));
   
  //!! Unknown function fftshift ,the original calling sequence is used
  aftf(:,t) = 2*real(fftshift(fft(x,-1)));
end
 
// abstf = abs(aftf);
abstf = aftf;
 
//!  mtlb_max(abstf) may be replaced by 
//!     max(abstf) if abstfis a vector
//!     max(abstf,'r') if abstfis a matrix
 
//!  mtlb_max(mtlb_max(abstf)) may be replaced by 
//!     max(mtlb_max(abstf)) if mtlb_max(abstf)is a vector
//!     max(mtlb_max(abstf),'r') if mtlb_max(abstf)is a matrix
tfmax = mtlb_max(mtlb_max(abstf));
 
//! mtlb_min(abstf) may be replaced by 
//!   min(abstf) if abstfis a vector
//!   min(abstf,'r') if abstfis a matrix
 
//! mtlb_min(mtlb_min(abstf)) may be replaced by 
//!   min(mtlb_min(abstf)) if mtlb_min(abstf)is a vector
//!   min(mtlb_min(abstf),'r') if mtlb_min(abstf)is a matrix
tfmin = mtlb_min(mtlb_min(abstf));
xset('colormap',1-graycolormap(256));
 
//!! Unknown function image ,the original calling sequence is used
image(linspace(0,1,n),linspace(0,1,n),256*(abstf-tfmin)/(tfmax-tfmin));
 
//!! Unknown function axis ,the original calling sequence is used
axis('xy');
xtitle('Alias Free Time-Frequency Distribution',' ',' ');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
 
// 
// Copyright (c) 1994-5, Shaobing Chen
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
