function [afwig]=WVDist_AF(sig)
afwig=[];
// WVDist_AF -- Alias-Free Wigner-Ville Distribution
//  Usage
//    afwig = WVDist_AF(sig)
//  Inputs
//    sig     1-d signal
//  Outputs
//    afwig   complex-valued matrix representing the alias-free
//            Wigner-Ville distribution of zero-extended signal with
//            rows corresponding to frequencies and columns corresponding
//            to times.
// 
//  Side Effects
//    Image Plot of the alias-free Wigner-Ville distribution
// 
//  See Also
//    WVDist, WVDist_AF, ImagePhasePlane
// 
//  References
//   Jechang Jeong and William J. Williams,
//   """"Alias-Free Generalized Discrete-Time Time-Frequency Distribution,""""
//   IEEE Transactions on Signal Processing, vol. 40, pp. 2757-2765.
// 
 
sig = sig(:);
 
//! unknown arg type, using mtlb_length 
n = mtlb_length(sig);
f = [zeros(n,1);sig;zeros(n,1)];
afwig = zeros(n,n);
ix = 0:n/2-1;
zerosn = zeros(n,1);
 
for t = 1:n
  tplus = n+t+ix;
  tminus = n+t-ix;
  x = zerosn;
  //even indices
  x(1:2:n) = f(tplus) .* f(tminus)
  //odd indices
  x(2:2:n) = (f(tplus+1) .* f(tminus)+f(tplus) .* f(tminus-1))/2
   
  //!! Unknown function fftshift ,the original calling sequence is used
  afwig(:,t) = 2*fftshift(fft(x,-1));
end
 
abstf = real(afwig);
 
//!  mtlb_max(abstf) may be replaced by 
//!     max(abstf) if abstfis a vector
//!     max(abstf,'r') if abstfis a matrix
 
//!  mtlb_max(mtlb_max(abstf)) may be replaced by 
//!     max(mtlb_max(abstf)) if mtlb_max(abstf)is a vector
//!     max(mtlb_max(abstf),'r') if mtlb_max(abstf)is a matrix
tfmax = mtlb_max(mtlb_max(abstf));
 
//! mtlb_min(abstf) may be replaced by 
//!   min(abstf) if abstfis a vector
//!   min(abstf,'r') if abstfis a matrix
 
//! mtlb_min(mtlb_min(abstf)) may be replaced by 
//!   min(mtlb_min(abstf)) if mtlb_min(abstf)is a vector
//!   min(mtlb_min(abstf),'r') if mtlb_min(abstf)is a matrix
tfmin = mtlb_min(mtlb_min(abstf));
xset('colormap',1-graycolormap(256));
 
//!! Unknown function image ,the original calling sequence is used
image(linspace(0,1,n),linspace(0,1,n),256*(abstf-tfmin)/(tfmax-tfmin));
 
//!! Unknown function axis ,the original calling sequence is used
axis('xy');
xtitle('Alias Free Wigner Distribution',' ',' ');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
 
// 
// Copyright (c) 1994-5, Shaobing Chen
// 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
