function [afwig]=WignerDist(sig)
afwig=[];
// WignerDist -- Alias-Free Wigner-Ville Distribution
//  Usage
//    afwig = WignerDist(sig)
//  Inputs
//    sig     1-d signal
//  Outputs
//    afwig   complex-valued matrix representing the alias-free
//            Wigner-Ville distribution of zero-extended signal with
//            rows corresponding to frequencies and columns corresponding
//            to times.
// 
//  Side Effects
//    Image Plot of the alias-free Wigner-Ville distribution
// 
//  See Also
// Interpol2
// 
//  References
//   Mallat's book, sections 4.5.1 and 4.5.4
// 
sig = sig(:);
 
//! unknown arg type, using mtlb_length 
N = mtlb_length(sig);
sig = Interpol2(sig);
f = [zeros(2*N,1),sig,zeros(2*N,1)];
afwig = zeros(N,N);
q = 0:2*N-1;
p(1,1:N) = q(1:N);
 
//! p = mtlb_i(p,N+1:2*N,q(N+1:2*N)-2*N) may be replaced by p(N+1:2*N) = q(N+1:2*N)-2*N
//!   if p is not a  vector
//!   or if p and q(N+1:2*N)-2*N are both row or column vectors
p = mtlb_i(p,N+1:2*N,q(N+1:2*N)-2*N)
for n = 1:N
  nplus = 2*n+p;
  nminus = 2*n-p;
  x = f(2*N+nplus) .* conj(f(2*N+nminus));
  aux = fft(x,-1);
  afwig(:,n) = aux(1:2:2*N-1)';
end
// this should be zero :
 
//!  mtlb_max(abs(imag(afwig(1:N/2,:)))) may be replaced by 
//!     max(abs(imag(afwig(1:N/2,:)))) if abs(imag(afwig(1:N/2,:)))is a vector
//!     max(abs(imag(afwig(1:N/2,:))),'r') if abs(imag(afwig(1:N/2,:)))is a matrix
 
//!  mtlb_max(mtlb_max(abs(imag(afwig(1:N/2,:))))) may be replaced by 
//!     max(mtlb_max(abs(imag(afwig(1:N/2,:))))) if mtlb_max(abs(imag(afwig(1:N/2,:))))is a vector
//!     max(mtlb_max(abs(imag(afwig(1:N/2,:)))),'r') if mtlb_max(abs(imag(afwig(1:N/2,:))))is a matrix
mtlb_max(mtlb_max(abs(imag(afwig(1:N/2,:)))));
abstf = real(afwig(1:N/2,:)) .* bool2s(real(afwig(1:N/2,:))>=zeros(N/2,N));
 
//!  mtlb_max(abstf) may be replaced by 
//!     max(abstf) if abstfis a vector
//!     max(abstf,'r') if abstfis a matrix
 
//!  mtlb_max(mtlb_max(abstf)) may be replaced by 
//!     max(mtlb_max(abstf)) if mtlb_max(abstf)is a vector
//!     max(mtlb_max(abstf),'r') if mtlb_max(abstf)is a matrix
tfmax = mtlb_max(mtlb_max(abstf));
 
//! mtlb_min(abstf) may be replaced by 
//!   min(abstf) if abstfis a vector
//!   min(abstf,'r') if abstfis a matrix
 
//! mtlb_min(mtlb_min(abstf)) may be replaced by 
//!   min(mtlb_min(abstf)) if mtlb_min(abstf)is a vector
//!   min(mtlb_min(abstf),'r') if mtlb_min(abstf)is a matrix
tfmin = mtlb_min(mtlb_min(abstf));
xset('colormap',1-graycolormap(256));
 
//!! Unknown function image ,the original calling sequence is used
image(linspace(0,N,N),linspace(0,N/2,N/2),256*(abstf-tfmin)/(tfmax-tfmin));
 
//!! Unknown function axis ,the original calling sequence is used
axis('xy');
xtitle('',' ',' ');
xtitle(' ','Time',' ');
xtitle(' ',' ','Frequency');
 
// Written by Maureen Clerc and Jerome Kalifa, 1997
// clerc@cmapx.polytechnique.fr, kalifa@cmapx.polytechnique.fr
 
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
