function []=AutoImage(img,x,y)
[nargout,nargin] = argn(0)
// AutoImage -- Image display of object assuming arbitrary values
//  Usage
//    AutoImage(img [,x,y])
//  Inputs
//    img     2-d image
//    x,y     where x and y are vectors, specifies the labeling of
//         X- and Y-axes, but produces the same image as AutoImage(img).
// 
//  Side Effects
//    The object img, assuming arbitrary values, is scaled to the 
//    range (0,255) and displayed as an image with 256 shades of gray.
// 
//  Description
//    If the object is already scaled to the range (0,255) you may
//    use GrayImage.
// 
//  See Also
//    GrayImage
// 
 
 
//! mtlb_min(img) may be replaced by 
//!   min(img) if imgis a vector
//!   min(img,'r') if imgis a matrix
 
//! mtlb_min(mtlb_min(img)) may be replaced by 
//!   min(mtlb_min(img)) if mtlb_min(img)is a vector
//!   min(mtlb_min(img),'r') if mtlb_min(img)is a matrix
mmin = mtlb_min(mtlb_min(img));
 
//!  mtlb_max(img) may be replaced by 
//!     max(img) if imgis a vector
//!     max(img,'r') if imgis a matrix
 
//!  mtlb_max(mtlb_max(img)) may be replaced by 
//!     max(mtlb_max(img)) if mtlb_max(img)is a vector
//!     max(mtlb_max(img),'r') if mtlb_max(img)is a matrix
mmax = mtlb_max(mtlb_max(img));

 
xset('window',max(winsid()+1));
set('figure_style','new')
fx=get('current_figure');
fx.visible='off';
ncolor=60;
h2=graycolormap(ncolor);
xset('colormap',h2)


if nargin==1 then
   
  //!! Unknown function image ,the original calling sequence is used
  //  image(256*(img-mmin)/(mmax-mmin));
  grayplot(1:size(toto,1),1:size(toto,2),256*(img-mmin)/(mmax-mmin)); // mod Ron
else
   
  //!! Unknown function image ,the original calling sequence is used
  // image(x,y,256*(img-mmin)/(mmax-mmin));
  grayplot(x,y,256*(img-mmin)/(mmax-mmin));
end
ax=get('current_axes'); 
ax.axes_visible='off';
fx.visible='on';
 
//!! Unknown function axis ,the original calling sequence is used
//axis('image');
//xset('colormap',graycolormap(256));
 
 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
 
