function []=toon0331()
// toon0331 -- Behavior of Wavelet Transform of Singularities
// 
//     Here we analyze 4 functions:
// 
//             Ramp = t - (t >= .37);
//           Crease = exp(-4*abs(t - .37));
//             Cusp = sqrt(abs(t - .37));
//             Sing = 1 ./abs(t - (k+.5)/2048);
// 
//     These have singularities of degree 0, 1, 1/2, and -1,
//        respectively.
// 
n = 4096;
t = (1:n) ./ n;
Ramp = t-(t>=0.37);
Crease = exp(-4*abs(t-0.37));
Cusp = sqrt(abs(t-0.37));
k = floor(n*0.37);
Sing = 1 ./ abs(t-(k+0.5)/n);
Sing = Sing ./ norm(Sing) .* 20;
// 
xsetech([0/2,0/2,1/2,1/2]);
mtlb_plot(t,Sing);
xtitle(' Sing',' ',' ');
xsetech([1/2,0/2,1/2,1/2]);
mtlb_plot(t,Ramp);
xtitle(' Ramp',' ',' ');
xsetech([0/2,1/2,1/2,1/2]);
mtlb_plot(t,Cusp);
xtitle(' Cusp',' ',' ');
xsetech([1/2,1/2,1/2,1/2]);
mtlb_plot(t,Crease);
xtitle(' Crease',' ',' ');
// 
// 
//   
// Part of WaveLab Version 802
// Built Sunday, October 3, 1999 8:52:27 AM
// This is Copyrighted Material
// For Copying permissions see COPYING.m
// Comments? e-mail wavelab@stat.stanford.edu
//   
// 
